from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCFS_SetDictFile(int windowsIndex, int dictIndex, char* file);
def HD识字_设置字库(窗口序号: int, 字库序号: int, 字库文件: str) -> int:
    """
    设置当前像素识字的字库文件（为了提高识别效率，不支持多线程）
    
    Args:
        窗口序号: 窗口序号
        字库序号: 字库序号，自定义整数类型，枚举类型，宏定义，不要小于0
        字库文件: 字库文件名字（可以加路径），最后寻找路径：全局路径（HCRES_SetResPath设置路径）+ file
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCFS_SetDictFile = hd.HCFS_SetDictFile
    HCFS_SetDictFile.restype = ctypes.c_int64
    HCFS_SetDictFile.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p]
    
    ret = HCFS_SetDictFile(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(字库序号),
        auto_encode(字库文件)
    )
    return ret

# INT64 __stdcall HCFS_SetDictFileEx(int windowsIndex, int dictIndex, char* file);
def HD识字_设置字库Ex(窗口序号: int, 字库序号: int, 字库文件: str) -> int:
    """
    设置当前像素识字的字库文件（为了提高识别效率，不支持多线程）（扩展版本）
    
    Args:
        窗口序号: 窗口序号
        字库序号: 字库序号，自定义整数类型，枚举类型，宏定义，不要小于0
        字库文件: 字库文件名字（可以加路径），最后寻找路径：全局路径（HCRES_SetResPath设置路径）+ file
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCFS_SetDictFileEx = hd.HCFS_SetDictFileEx
    HCFS_SetDictFileEx.restype = ctypes.c_int64
    HCFS_SetDictFileEx.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p]
    
    ret = HCFS_SetDictFileEx(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(字库序号),
        auto_encode(字库文件)
    )
    return ret

# INT64 __stdcall HCFS_SetDictFileExx(int windowsIndex, int dictIndex, char* file, char* password);
def HD识字_设置字库Exx(窗口序号: int, 字库序号: int, 字库文件: str, 密码: str = None) -> int:
    """
    设置当前像素识字的字库文件（为了提高识别效率，不支持多线程）
    建议在登录回调中最开始初始化调用
    其他线程需要那个序号就切换那个序号HCFS_SwitchCurDictFile
    调用一次会给所有窗口序号添加当前设置的字库文件
    
    Args:
        窗口序号: 窗口序号
        字库序号: 字库序号，自定义整数类型，枚举类型，宏定义，不要小于0
        字库文件: 字库文件名字（可以加路径）
        密码: 密码，使用综合工具进行加密，默认None
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCFS_SetDictFileExx = hd.HCFS_SetDictFileExx
    HCFS_SetDictFileExx.restype = ctypes.c_int64
    HCFS_SetDictFileExx.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p]
    
    ret = HCFS_SetDictFileExx(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(字库序号),
        auto_encode(字库文件),
        auto_encode(密码) if 密码 else None
    )
    return ret

# INT64 __stdcall HCFS_SwitchCurDictFile(int windowsIndex, int dictIndex);
def HD识字_切换字库序号(窗口序号: int, 字库序号: int) -> int:
    """
    设置当前像素识字的字库文件（为了提高识别效率，不支持多线程）请在主执行线程中最开始初始化调用
    
    Args:
        窗口序号: 窗口序号
        字库序号: 字库序号，自定义整数类型，枚举类型，宏定义，不要小于0
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCFS_SwitchCurDictFile = hd.HCFS_SwitchCurDictFile
    HCFS_SwitchCurDictFile.restype = ctypes.c_int64
    HCFS_SwitchCurDictFile.argtypes = [ctypes.c_int32, ctypes.c_int32]
    
    ret = HCFS_SwitchCurDictFile(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(字库序号)
    )
    return ret

# __int64 __stdcall HCFS_GetCurDictInfo(__int32 窗口序号);
def HD识字_获取当前字库(窗口序号: int) -> int:
    """
    设置当前像素识字的字库文件(为了提高识别效率,不支持多线程) 请在主执行线程中最开始初始化调用
    :param 窗口序号: 窗口序号
    :return: 返回值代码(查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFS_GetCurDictInfo = hd.HCFS_GetCurDictInfo
    HCFS_GetCurDictInfo.restype = ctypes.c_int64
    HCFS_GetCurDictInfo.argtypes = [ctypes.c_int32]

    ret = HCFS_GetCurDictInfo(
        ctypes.c_int32(窗口序号)
    )
    return ret

# __int64 __stdcall HCFS_GetCurDictIndex(__int32 窗口序号);
def HD识字_获取当前字库序号(窗口序号: int) -> int:
    """
    获取当前线程绑定的字库索引 (支持多线程)
    :param 窗口序号: 窗口序号
    :return: 返回值代码(查看HD返回值表) 或者 返回大于等于0的值是当前线程绑定的字库索引
    """
    hd = Config.get_hd()

    HCFS_GetCurDictIndex = hd.HCFS_GetCurDictIndex
    HCFS_GetCurDictIndex.restype = ctypes.c_int64
    HCFS_GetCurDictIndex.argtypes = [ctypes.c_int32]

    ret = HCFS_GetCurDictIndex(
        ctypes.c_int32(窗口序号)
    )
    return ret


# INT64 __stdcall HCFS_FindStr(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR str, LPCSTR deltaColor, double sim, long bfx, int dirType=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_单字符找字(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 字符串: str, 偏色: str, 相似度: float, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    在客户区范围内找字(只支持单字符串并且是单字符字库)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: x坐标
        y: y坐标
        宽度: 宽度
        高度: 高度
        字符串: 需要找的字符串
        偏色: 偏色(如: ffffff-000000|1c1c1c-000000) RGB 十六进制 "|" 分割 多点找字
        相似度: 整个像素矩阵的相似度
        是否开启反向相似度: 是否开启反向相似度(开启更精准,但是对于一些小范围的可能会过滤掉,一般开启就行)
        排序方向类型: 排序类型 / 方向类型 排序/方向类型
        水平间距: 字体水平间距 默认11像素
        垂直间距: 字体垂直间距 默认11像素
        周围占比: 一个字的周围占比 默认0.1
        是否独占11: 一个字是否独占11像素 默认真/TRUE/开启
        
    Returns:
        返回值代码(查看HD返回值表) 或者 字符串用HCEnv_GetRetJson获取
    """
    hd = Config.get_hd()

    HCFS_FindStr = hd.HCFS_FindStr
    HCFS_FindStr.restype = ctypes.c_int64
    HCFS_FindStr.argtypes = [
        ctypes.c_int32,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_char_p,
        ctypes.c_char_p,
        ctypes.c_double,
        ctypes.c_long,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_double,
        ctypes.c_bool
    ]

    字符串_bytes = auto_encode(字符串)
    偏色_bytes = auto_encode(偏色)

    ret = HCFS_FindStr(
        ctypes.c_int32(窗口序号),
        ctypes.c_long(x),
        ctypes.c_long(y),
        ctypes.c_long(宽度),
        ctypes.c_long(高度),
        ctypes.c_char_p(字符串_bytes),
        ctypes.c_char_p(偏色_bytes),
        ctypes.c_double(相似度),
        ctypes.c_long(是否开启反向相似度),
        ctypes.c_int32(排序方向类型),
        ctypes.c_int32(水平间距),
        ctypes.c_int32(垂直间距),
        ctypes.c_double(周围占比),
        ctypes.c_bool(是否独占11)
    )
    return ret


# INT64 __stdcall HCFS_FindStrEx(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR str, LPCSTR deltaColor, double sim, long bfx, int dirType=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_单字符找字Ex(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 字符串: str, 偏色: str, 相似度: float, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    在客户区范围内找字(支持多个字符串并且是单字符字库)(扩展版本)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: x坐标
        y: y坐标
        宽度: 宽度
        高度: 高度
        字符串: 需要找的字符串 支持多字符串 例如: 大理|无量山|溶洞 "|" 分割
        偏色: 偏色(如: ffffff-000000|1c1c1c-000000) RGB 十六进制 "|" 分割 多点找字
        相似度: 整个像素矩阵的相似度
        是否开启反向相似度: 是否开启反向相似度(开启更精准,但是对于一些小范围的可能会过滤掉,一般开启就行)
        排序方向类型: 排序类型 / 方向类型 排序/方向类型
        水平间距: 字体水平间距 默认11像素
        垂直间距: 字体垂直间距 默认11像素
        周围占比: 一个字的周围占比 默认0.1
        是否独占11: 一个字是否独占11像素 默认真/TRUE/开启
        
    Returns:
        返回值代码(查看HD返回值表) 或者 字符串用HCEnv_GetRetJson获取
    """
    hd = Config.get_hd()

    HCFS_FindStrEx = hd.HCFS_FindStrEx
    HCFS_FindStrEx.restype = ctypes.c_int64
    HCFS_FindStrEx.argtypes = [
        ctypes.c_int32,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_char_p,
        ctypes.c_char_p,
        ctypes.c_double,
        ctypes.c_long,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_double,
        ctypes.c_bool
    ]

    字符串_bytes = auto_encode(字符串)
    偏色_bytes = auto_encode(偏色)

    # 调用C函数
    ret = HCFS_FindStrEx(
        ctypes.c_int32(窗口序号),
        ctypes.c_long(x),
        ctypes.c_long(y),
        ctypes.c_long(宽度),
        ctypes.c_long(高度),
        ctypes.c_char_p(字符串_bytes),
        ctypes.c_char_p(偏色_bytes),
        ctypes.c_double(相似度),
        ctypes.c_long(是否开启反向相似度),
        ctypes.c_int32(排序方向类型),
        ctypes.c_int32(水平间距),
        ctypes.c_int32(垂直间距),
        ctypes.c_double(周围占比),
        ctypes.c_bool(是否独占11)
    )
    return ret


# INT64 __stdcall HCFS_FindStrExx(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR str, LPCSTR deltaColor, double sim, long bfx, int dirType=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_单字符找字Exx(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 字符串: str, 偏色: str, 相似度: float, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    在客户区范围内找字(支持多个字符串并且是单字符字库)(扩展版本)找到一个就返回
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: x坐标
        y: y坐标
        宽度: 宽度
        高度: 高度
        字符串: 需要找的字符串 支持多字符串 例如: 大理|无量山|溶洞 "|" 分割
        偏色: 偏色(如: ffffff-000000|1c1c1c-000000) RGB 十六进制 "|" 分割 多点找字
        相似度: 整个像素矩阵的相似度
        是否开启反向相似度: 是否开启反向相似度(开启更精准,但是对于一些小范围的可能会过滤掉,一般开启就行)
        排序方向类型: 排序类型 / 方向类型 排序/方向类型
        水平间距: 字体水平间距 默认11像素
        垂直间距: 字体垂直间距 默认11像素
        周围占比: 一个字的周围占比 默认0.1
        是否独占11: 一个字是否独占11像素 默认真/TRUE/开启
        
    Returns:
        返回值代码(查看HD返回值表) 或者 大于0表示:高4字节为x 低4字节为y 同时字符串信息存在json中
    """
    hd = Config.get_hd()

    HCFS_FindStrExx = hd.HCFS_FindStrExx
    HCFS_FindStrExx.restype = ctypes.c_int64
    HCFS_FindStrExx.argtypes = [
        ctypes.c_int32,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_char_p,
        ctypes.c_char_p,
        ctypes.c_double,
        ctypes.c_long,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_double,
        ctypes.c_bool
    ]

    字符串_bytes = auto_encode(字符串)
    偏色_bytes = auto_encode(偏色)

    # 调用C函数
    ret = HCFS_FindStrExx(
        ctypes.c_int32(窗口序号),
        ctypes.c_long(x),
        ctypes.c_long(y),
        ctypes.c_long(宽度),
        ctypes.c_long(高度),
        ctypes.c_char_p(字符串_bytes),
        ctypes.c_char_p(偏色_bytes),
        ctypes.c_double(相似度),
        ctypes.c_long(是否开启反向相似度),
        ctypes.c_int32(排序方向类型),
        ctypes.c_int32(水平间距),
        ctypes.c_int32(垂直间距),
        ctypes.c_double(周围占比),
        ctypes.c_bool(是否独占11)
    )
    return ret


# INT64  __stdcall HCFS_FindStrMutilVPoints(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR str, LPCSTR color_format, double sim, long bfx, int dirType=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_列表单列找字(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 字符串: str, 偏色: str, 相似度: float, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    单字符串找 字库是字符串 例如:洛阳 多行 返回多个坐标 一行只找一列(一次)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: x坐标
        y: y坐标
        宽度: 宽度
        高度: 高度
        字符串: 需要找的字符串 支持多字符串 例如: 大理|无量山|溶洞 "|" 分割
        偏色: 偏色(如: ffffff-000000|1c1c1c-000000) RGB 十六进制 "|" 分割 多点找字
        相似度: 整个像素矩阵的相似度
        是否开启反向相似度: 是否开启反向相似度(开启更精准,但是对于一些小范围的可能会过滤掉,一般开启就行)
        排序方向类型: 排序类型 / 方向类型 排序/方向类型
        水平间距: 字体水平间距 默认11像素
        垂直间距: 字体垂直间距 默认11像素
        周围占比: 一个字的周围占比 默认0.1
        是否独占11: 一个字是否独占11像素 默认真/TRUE/开启
        
    Returns:
        返回值代码(查看HD返回值表) 或者 大于0表示:找到的数量
    """
    hd = Config.get_hd()

    HCFS_FindStrMutilVPoints = hd.HCFS_FindStrMutilVPoints
    HCFS_FindStrMutilVPoints.restype = ctypes.c_int64
    HCFS_FindStrMutilVPoints.argtypes = [
        ctypes.c_int32,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_char_p,
        ctypes.c_char_p,
        ctypes.c_double,
        ctypes.c_long,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_double,
        ctypes.c_bool
    ]

    字符串_bytes = auto_encode(字符串)
    偏色_bytes = auto_encode(偏色)

    # 调用C函数
    ret = HCFS_FindStrMutilVPoints(
        ctypes.c_int32(窗口序号),
        ctypes.c_long(x),
        ctypes.c_long(y),
        ctypes.c_long(宽度),
        ctypes.c_long(高度),
        ctypes.c_char_p(字符串_bytes),
        ctypes.c_char_p(偏色_bytes),
        ctypes.c_double(相似度),
        ctypes.c_long(是否开启反向相似度),
        ctypes.c_int32(排序方向类型),
        ctypes.c_int32(水平间距),
        ctypes.c_int32(垂直间距),
        ctypes.c_double(周围占比),
        ctypes.c_bool(是否独占11)
    )
    return ret


# INT64  __stdcall HCFS_FindStrMutilVPointsByFile(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR str, LPCSTR color_format, double sim, LPCSTR iamgeName, int bfx, int dirType=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_列表单列找字从文件(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 字符串: str, 偏色: str, 相似度: float, 图片名字: str, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    单字符串找 (原图从文件) 字库是字符串 例如:洛阳 多行 返回多个坐标 一行只找一列(一次)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: x坐标
        y: y坐标
        宽度: 宽度
        高度: 高度
        字符串: 需要找的字符串 支持多字符串 例如: 大理|无量山|溶洞 "|" 分割
        偏色: 偏色(如: ffffff-000000|1c1c1c-000000) RGB 十六进制 "|" 分割 多点找字
        相似度: 整个像素矩阵的相似度
        图片名字: bmp图片名字,支持加路径,不加路径则在全局路径找,图片后缀不要省略(支持绝对路径和相对路径)
        是否开启反向相似度: 是否开启反向相似度(开启更精准,但是对于一些小范围的可能会过滤掉,一般开启就行)
        排序方向类型: 排序类型 / 方向类型 排序/方向类型
        水平间距: 字体水平间距 默认11像素
        垂直间距: 字体垂直间距 默认11像素
        周围占比: 一个字的周围占比 默认0.1
        是否独占11: 一个字是否独占11像素 默认真/TRUE/开启
        
    Returns:
        返回值代码(查看HD返回值表) 或者 大于0表示:找到的数量
    """
    hd = Config.get_hd()

    HCFS_FindStrMutilVPointsByFile = hd.HCFS_FindStrMutilVPointsByFile
    HCFS_FindStrMutilVPointsByFile.restype = ctypes.c_int64
    HCFS_FindStrMutilVPointsByFile.argtypes = [
        ctypes.c_int32,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_char_p,
        ctypes.c_char_p,
        ctypes.c_double,
        ctypes.c_char_p,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_double,
        ctypes.c_bool
    ]

    字符串_bytes = auto_encode(字符串)
    偏色_bytes = auto_encode(偏色)
    图片名字_bytes = auto_encode(图片名字)

    # 调用C函数
    ret = HCFS_FindStrMutilVPointsByFile(
        ctypes.c_int32(窗口序号),
        ctypes.c_long(x),
        ctypes.c_long(y),
        ctypes.c_long(宽度),
        ctypes.c_long(高度),
        ctypes.c_char_p(字符串_bytes),
        ctypes.c_char_p(偏色_bytes),
        ctypes.c_double(相似度),
        ctypes.c_char_p(图片名字_bytes),
        ctypes.c_int32(是否开启反向相似度),
        ctypes.c_int32(排序方向类型),
        ctypes.c_int32(水平间距),
        ctypes.c_int32(垂直间距),
        ctypes.c_double(周围占比),
        ctypes.c_bool(是否独占11)
    )
    return ret


# INT64  __stdcall HCFS_FindStrMutilVPointsByMem(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR str, LPCSTR color_format, double sim, BYTE* data, int dataSize, int bfx, int dirType=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_列表单列找字从内存(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 字符串: str, 偏色: str, 相似度: float, 图片数据: bytes, 图片数据大小: int, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    单字符串找 (原图从内存) 字库是字符串 例如:洛阳 多行 返回多个坐标 一行只找一列(一次)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: x坐标
        y: y坐标
        宽度: 宽度
        高度: 高度
        字符串: 需要找的字符串 支持多字符串 例如: 大理|无量山|溶洞 "|" 分割
        偏色: 偏色(如: ffffff-000000|1c1c1c-000000) RGB 十六进制 "|" 分割 多点找字
        相似度: 整个像素矩阵的相似度
        图片数据: bmp图片格式的二进制内存数据首地址 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        图片数据大小: 图片数据大小
        是否开启反向相似度: 是否开启反向相似度(开启更精准,但是对于一些小范围的可能会过滤掉,一般开启就行)
        排序方向类型: 排序类型 / 方向类型 排序/方向类型
        水平间距: 字体水平间距 默认11像素
        垂直间距: 字体垂直间距 默认11像素
        周围占比: 一个字的周围占比 默认0.1
        是否独占11: 一个字是否独占11像素 默认真/TRUE/开启
        
    Returns:
        返回值代码(查看HD返回值表) 或者 大于0表示:找到的数量
    """
    hd = Config.get_hd()

    HCFS_FindStrMutilVPointsByMem = hd.HCFS_FindStrMutilVPointsByMem
    HCFS_FindStrMutilVPointsByMem.restype = ctypes.c_int64
    HCFS_FindStrMutilVPointsByMem.argtypes = [
        ctypes.c_int32,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_long,
        ctypes.c_char_p,
        ctypes.c_char_p,
        ctypes.c_double,
        ctypes.POINTER(ctypes.c_ubyte),
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_double,
        ctypes.c_bool
    ]

    字符串_bytes = auto_encode(字符串)
    偏色_bytes = auto_encode(偏色)

    # 将图片数据转换为ctypes数组
    图片数据_array = (ctypes.c_ubyte * 图片数据大小)(*图片数据)

    # 调用C函数
    ret = HCFS_FindStrMutilVPointsByMem(
        ctypes.c_int32(窗口序号),
        ctypes.c_long(x),
        ctypes.c_long(y),
        ctypes.c_long(宽度),
        ctypes.c_long(高度),
        ctypes.c_char_p(字符串_bytes),
        ctypes.c_char_p(偏色_bytes),
        ctypes.c_double(相似度),
        图片数据_array,
        ctypes.c_int32(图片数据大小),
        ctypes.c_int32(是否开启反向相似度),
        ctypes.c_int32(排序方向类型),
        ctypes.c_int32(水平间距),
        ctypes.c_int32(垂直间距),
        ctypes.c_double(周围占比),
        ctypes.c_bool(是否独占11)
    )
    return ret


# INT64 __stdcall HCFS_FindStrMutilHVPoints(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR str, LPCSTR color_format, double sim, long bfx, int dirType=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE)
def HD识字_列表多列找字(窗口序号: int, x: int, y: int, w: int, h: int, 字符串: str, 偏色: str, 相似度: float, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    多行多列找字(完整屏幕版)
    :param 窗口序号: 1开始的窗口索引
    :param x: 起始X坐标
    :param y: 起始Y坐标
    :param w: 区域宽度
    :param h: 区域高度
    :param 字符串: 要查找的字符串(支持"|"分割多个)
    :param 偏色: 颜色格式"RRGGBB-RRGGBB|..."
    :param 相似度: 0.0~1.0的相似度阈值
    :param 是否开启反向相似度: True/False
    :param 排序方向类型: 排序方向类型
    :param 水平间距: 文字水平间距(默认11像素)
    :param 垂直间距: 文字垂直间距(默认11像素)
    :param 周围占比: 字符周边占比(默认0.1)
    :param 是否独占11: 是否独占11像素区域
    :return: 结果数量或错误码
    """
    hd = Config.get_hd()
    func = hd.HCFS_FindStrMutilHVPoints
    func.restype = ctypes.c_int64
    func.argtypes = [
        ctypes.c_int, ctypes.c_long, ctypes.c_long, ctypes.c_long, ctypes.c_long,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double,
        ctypes.c_long, ctypes.c_int, ctypes.c_int, ctypes.c_int,
        ctypes.c_double, ctypes.c_bool
    ]

    str_bytes = auto_encode(字符串)
    color_bytes = auto_encode(偏色)

    return func(
        窗口序号, x, y, w, h,
        str_bytes, color_bytes, 相似度,
        是否开启反向相似度, 排序方向类型, 水平间距, 垂直间距,
        周围占比, 是否独占11
    )


# INT64  __stdcall HCFS_FindStrMutilHVPointsByFile(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR str, LPCSTR color_format, double sim, LPCSTR iamgeName, int bfx, int dirType= 0, int spaceH = 11, int spaceV = 11, double groundRate = 0.1, BOOL bOne11= TRUE);
def HD识字_列表多列找字从文件(窗口序号: int, x: int, y: int, w: int, h: int, 字符串: str, 偏色: str, 相似度: float, 图片文件名: str, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    从图片文件进行多行多列找字
    
    Args:
        窗口序号: 窗口序号
        x: x坐标
        y: y坐标  
        w: 宽度
        h: 高度
        字符串: 字符串
        偏色: 偏色
        相似度: 相似度
        图片文件名: 图片文件名
        是否开启反向相似度: 是否开启反向相似度
        排序方向类型: 排序方向类型
        水平间距: 水平间距
        垂直间距: 垂直间距
        周围占比: 周围占比
        是否独占11: 是否独占11
        
    Returns:
        返回值代码
    """
    hd = Config.get_hd()
    
    func = hd.HCFS_FindStrMutilHVPointsByFile
    func.restype = ctypes.c_int64
    func.argtypes = [
        ctypes.c_int, ctypes.c_long, ctypes.c_long, ctypes.c_long, ctypes.c_long,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double,
        ctypes.c_char_p,
        ctypes.c_int, ctypes.c_int, ctypes.c_int, ctypes.c_int,
        ctypes.c_double, ctypes.c_bool
    ]

    return func(
        窗口序号, x, y, w, h,
        auto_encode(字符串), auto_encode(偏色), 相似度,
        auto_encode(图片文件名), 是否开启反向相似度,
        排序方向类型, 水平间距, 垂直间距,
        周围占比, 是否独占11
    )


# INT64  __stdcall HCFS_FindStrMutilHVPointsByMem(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR str, LPCSTR color_format, double sim, BYTE* data, int dataSize, int bfx, int dirType= 0, int spaceH = 11, int spaceV = 11, double groundRate = 0.1, BOOL bOne11= TRUE);
def HD识字_列表多列找字从内存(窗口序号: int, x: int, y: int, w: int, h: int, 字符串: str, 偏色: str, 相似度: float, 图片数据: bytes, 数据大小: int, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    从内存图像数据找字
    
    Args:
        窗口序号: 窗口序号
        x: x坐标
        y: y坐标
        w: 宽度
        h: 高度
        字符串: 字符串
        偏色: 偏色
        相似度: 相似度
        图片数据: 图片数据 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        数据大小: 数据大小
        是否开启反向相似度: 是否开启反向相似度
        排序方向类型: 排序方向类型
        水平间距: 水平间距
        垂直间距: 垂直间距
        周围占比: 周围占比
        是否独占11: 是否独占11
        
    Returns:
        返回值代码
    """
    hd = Config.get_hd()
    
    func = hd.HCFS_FindStrMutilHVPointsByMem
    func.restype = ctypes.c_int64
    func.argtypes = [
        ctypes.c_int, ctypes.c_long, ctypes.c_long, ctypes.c_long, ctypes.c_long,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double,
        ctypes.POINTER(ctypes.c_ubyte), ctypes.c_int,
        ctypes.c_int, ctypes.c_int, ctypes.c_int, ctypes.c_int,
        ctypes.c_double, ctypes.c_bool
    ]

    buffer = (ctypes.c_ubyte * 数据大小).from_buffer_copy(图片数据)

    return func(
        窗口序号, x, y, w, h,
        auto_encode(字符串), auto_encode(偏色), 相似度,
        buffer, 数据大小, 是否开启反向相似度,
        排序方向类型, 水平间距, 垂直间距,
        周围占比, 是否独占11
    )


# INT64 __stdcall HCFS_FindStrMutilsAuto(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR strs, LPCSTR color_format, double sim, long bfx, int dirType=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_自动识字(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 字符串: str, 偏色: str, 相似度: float, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    支持多字符串识别的自动识字功能
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: x坐标
        y: y坐标
        宽度: 宽度
        高度: 高度
        字符串: 需要找的字符串，支持多字符串分割（示例："大理|无量山|溶洞"）
        偏色: RGB偏色设置（示例："ffffff-000000|1c1c1c-000000"）
        相似度: 整个像素矩阵的相似度
        是否开启反向相似度: 是否开启反向相似度
        排序方向类型: 排序类型/方向类型
        水平间距: 字体水平间距（默认11像素）
        垂直间距: 字体垂直间距（默认11像素）
        周围占比: 一个字的周围占比（默认0.1）
        是否独占11: 一个字是否独占11像素（默认True）
        
    Returns:
        返回值代码或成功找到返回MAKEXYWHTO8(fx1, fy1, w, h)
    """
    hd = Config.get_hd()

    func = hd.HCFS_FindStrMutilsAuto
    func.restype = ctypes.c_int64
    func.argtypes = [
        ctypes.c_int, ctypes.c_long, ctypes.c_long, ctypes.c_long, ctypes.c_long,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_long,
        ctypes.c_int, ctypes.c_int, ctypes.c_int, ctypes.c_double, ctypes.c_bool
    ]

    return func(
        窗口序号, x, y, 宽度, 高度,
        auto_encode(字符串), auto_encode(偏色), 相似度,
        是否开启反向相似度, 排序方向类型, 水平间距, 垂直间距,
        周围占比, 是否独占11
    )


# INT64 __stdcall HCFS_FindStrMutilsAutoByFile(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR strs, LPCSTR color_format, double sim, LPCSTR iamgeName, long bfx, int dirType=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_自动识字从文件(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 字符串: str, 偏色: str, 相似度: float, 图片名字: str, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    从文件中识别多字符串的自动识字功能
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: x坐标
        y: y坐标
        宽度: 宽度
        高度: 高度
        字符串: 需要找的字符串，支持多字符串分割（示例："大理|无量山|溶洞"）
        偏色: RGB偏色设置（示例："ffffff-000000|1c1c1c-000000"）
        相似度: 整个像素矩阵的相似度
        图片名字: bmp图片名字，支持加路径
        是否开启反向相似度: 是否开启反向相似度
        排序方向类型: 排序类型/方向类型
        水平间距: 字体水平间距（默认11像素）
        垂直间距: 字体垂直间距（默认11像素）
        周围占比: 一个字的周围占比（默认0.1）
        是否独占11: 一个字是否独占11像素（默认True）
        
    Returns:
        返回值代码或成功找到返回MAKEXYWHTO8(fx1, fy1, w, h)
    """
    hd = Config.get_hd()

    func = hd.HCFS_FindStrMutilsAutoByFile
    func.restype = ctypes.c_int64
    func.argtypes = [
        ctypes.c_int, ctypes.c_long, ctypes.c_long, ctypes.c_long, ctypes.c_long,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_char_p,
        ctypes.c_long, ctypes.c_int, ctypes.c_int, ctypes.c_int,
        ctypes.c_double, ctypes.c_bool
    ]

    return func(
        窗口序号, x, y, 宽度, 高度,
        auto_encode(字符串), auto_encode(偏色), 相似度,
        auto_encode(图片名字), 是否开启反向相似度,
        排序方向类型, 水平间距, 垂直间距,
        周围占比, 是否独占11
    )


# INT64 __stdcall HCFS_FindStrMutilsAutoByMem(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR strs, LPCSTR color_format, double sim, BYTE* data, int dataSize, int bfx, int dirType=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_自动识字从内存(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 字符串: str, 偏色: str, 相似度: float, 图片数据: bytes, 图片数据大小: int, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    从内存中识别多字符串的自动识字功能
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: x坐标
        y: y坐标
        宽度: 宽度
        高度: 高度
        字符串: 需要找的字符串，支持多字符串分割（示例："大理|无量山|溶洞"）
        偏色: RGB偏色设置（示例："ffffff-000000|1c1c1c-000000"）
        相似度: 整个像素矩阵的相似度
        图片数据: 图片的二进制数据
        图片数据大小: 图片数据的大小
        是否开启反向相似度: 是否开启反向相似度
        排序方向类型: 排序类型/方向类型
        水平间距: 字体水平间距（默认11像素）
        垂直间距: 字体垂直间距（默认11像素）
        周围占比: 一个字的周围占比（默认0.1）
        是否独占11: 一个字是否独占11像素（默认True）
        
    Returns:
        返回值代码或成功找到返回MAKEXYWHTO8(fx1, fy1, w, h)
    """
    hd = Config.get_hd()

    func = hd.HCFS_FindStrMutilsAutoByMem
    func.restype = ctypes.c_int64
    func.argtypes = [
        ctypes.c_int, ctypes.c_long, ctypes.c_long, ctypes.c_long, ctypes.c_long,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double,
        ctypes.POINTER(ctypes.c_ubyte), ctypes.c_int,
        ctypes.c_int, ctypes.c_int, ctypes.c_int, ctypes.c_int,
        ctypes.c_double, ctypes.c_bool
    ]

    buffer = (ctypes.c_ubyte * 图片数据大小).from_buffer_copy(图片数据)

    return func(
        窗口序号, x, y, 宽度, 高度,
        auto_encode(字符串), auto_encode(偏色), 相似度,
        buffer, 图片数据大小, 是否开启反向相似度,
        排序方向类型, 水平间距, 垂直间距,
        周围占比, 是否独占11
    )


# INT64 __stdcall HCFS_FindStrMutilsAutoEx(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR strs, LPCSTR color_format, double sim, long bfx, int dirType=0, int bFindOne=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_自动识字Ex(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, CA字符串: str, 偏色: str, 相似度: float, 是否开启反向相似度: int, 排序方向类型: int = 0, 是否找到一个就返回: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    扩展版自动识字功能，支持找到一个就返回的控制
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: x坐标
        y: y坐标
        宽度: 宽度
        高度: 高度
        CA字符串: 需要找的字符串，支持多字符串分割
        偏色: RGB偏色设置
        相似度: 整个像素矩阵的相似度
        是否开启反向相似度: 是否开启反向相似度
        排序方向类型: 排序类型/方向类型
        是否找到一个就返回: 是否找到一个就返回（默认0）
        水平间距: 字体水平间距（默认11像素）
        垂直间距: 字体垂直间距（默认11像素）
        周围占比: 一个字的周围占比（默认0.1）
        是否独占11: 一个字是否独占11像素（默认True）
        
    Returns:
        返回值代码或成功找到返回MAKEXYWHTO8(fx1, fy1, w, h)
    """
    hd = Config.get_hd()

    func = hd.HCFS_FindStrMutilsAutoEx
    func.restype = ctypes.c_int64
    func.argtypes = [
        ctypes.c_int, ctypes.c_long, ctypes.c_long, ctypes.c_long, ctypes.c_long,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_long,
        ctypes.c_int, ctypes.c_int, ctypes.c_int, ctypes.c_int,
        ctypes.c_double, ctypes.c_bool
    ]

    return func(
        窗口序号, x, y, 宽度, 高度,
        auto_encode(CA字符串), auto_encode(偏色), 相似度,
        是否开启反向相似度, 排序方向类型, 是否找到一个就返回,
        水平间距, 垂直间距, 周围占比, 是否独占11
    )

# INT64  __stdcall HCFS_FindStrMutilsAutoByFileEx(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR strs, LPCSTR color_format, double sim, LPCSTR iamgeName, long bfx, int dirType=0, int bFindOne=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_自动识字从文件Ex(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 字符串: str, 偏色: str, 相似度: float, 图片名字: str, 是否开启反向相似度: int, 排序方向类型: int = 0, 是否找到一个就返回: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    扩展版从文件识别多字符串的自动识字功能，支持找到一个就返回
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: x坐标
        y: y坐标
        宽度: 宽度
        高度: 高度
        字符串: 需要找的字符串，支持多字符串分割（示例："大理|无量山|溶洞"）
        偏色: RGB偏色设置（示例："ffffff-000000|1c1c1c-000000"）
        相似度: 整个像素矩阵的相似度
        图片名字: bmp图片名字，支持加路径
        是否开启反向相似度: 是否开启反向相似度
        排序方向类型: 排序类型/方向类型
        是否找到一个就返回: 是否找到一个就返回（默认0）
        水平间距: 字体水平间距（默认11像素）
        垂直间距: 字体垂直间距（默认11像素）
        周围占比: 一个字的周围占比（默认0.1）
        是否独占11: 一个字是否独占11像素（默认True）
        
    Returns:
        返回值代码或成功找到返回MAKEXYWHTO8(fx1, fy1, w, h)
    """
    hd = Config.get_hd()

    func = hd.HCFS_FindStrMutilsAutoByFileEx
    func.restype = ctypes.c_int64
    func.argtypes = [
        ctypes.c_int, ctypes.c_long, ctypes.c_long, ctypes.c_long, ctypes.c_long,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_char_p,
        ctypes.c_long, ctypes.c_int, ctypes.c_int, ctypes.c_int,
        ctypes.c_int, ctypes.c_double, ctypes.c_bool
    ]

    return func(
        窗口序号, x, y, 宽度, 高度,
        auto_encode(字符串), auto_encode(偏色), 相似度,
        auto_encode(图片名字), 是否开启反向相似度,
        排序方向类型, 是否找到一个就返回, 水平间距,
        垂直间距, 周围占比, 是否独占11
    )


# INT64  __stdcall HCFS_FindStrMutilsAutoByMemEx(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR strs, LPCSTR color_format, double sim, BYTE* data, int dataSize, int bfx, int dirType=0, int bFindOne=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_自动识字从内存Ex(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 字符串: str, 偏色: str, 相似度: float, 图片数据: bytes, 图片数据大小: int, 是否开启反向相似度: int, 排序方向类型: int = 0, 是否找到一个就返回: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    扩展版从内存识别多字符串的自动识字功能，支持找到一个就返回
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: x坐标
        y: y坐标
        宽度: 宽度
        高度: 高度
        字符串: 需要找的字符串，支持多字符串分割（示例："大理|无量山|溶洞"）
        偏色: RGB偏色设置（示例："ffffff-000000|1c1c1c-000000"）
        相似度: 整个像素矩阵的相似度
        图片数据: 图片的二进制数据
        图片数据大小: 图片数据的大小
        是否开启反向相似度: 是否开启反向相似度
        排序方向类型: 排序类型/方向类型
        是否找到一个就返回: 是否找到一个就返回（默认0）
        水平间距: 字体水平间距（默认11像素）
        垂直间距: 字体垂直间距（默认11像素）
        周围占比: 一个字的周围占比（默认0.1）
        是否独占11: 一个字是否独占11像素（默认True）
        
    Returns:
        返回值代码或成功找到返回MAKEXYWHTO8(fx1, fy1, w, h)
    """
    hd = Config.get_hd()

    func = hd.HCFS_FindStrMutilsAutoByMemEx
    func.restype = ctypes.c_int64
    func.argtypes = [
        ctypes.c_int, ctypes.c_long, ctypes.c_long, ctypes.c_long, ctypes.c_long,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double,
        ctypes.POINTER(ctypes.c_ubyte), ctypes.c_int,
        ctypes.c_long, ctypes.c_int, ctypes.c_int, ctypes.c_int,
        ctypes.c_int, ctypes.c_double, ctypes.c_bool
    ]

    buffer = (ctypes.c_ubyte * 图片数据大小).from_buffer_copy(图片数据)

    return func(
        窗口序号, x, y, 宽度, 高度,
        auto_encode(字符串), auto_encode(偏色), 相似度,
        buffer, 图片数据大小, 是否开启反向相似度,
        排序方向类型, 是否找到一个就返回, 水平间距,
        垂直间距, 周围占比, 是否独占11
    )


# INT64  __stdcall HCFS_FindStrMutil(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR str, LPCSTR color_format, double sim, long bfx, int dirType=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_多字符识字(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 字符串: str, 偏色: str, 相似度: float, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    多字符识别功能，字库为字符串格式
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: x坐标
        y: y坐标
        宽度: 宽度
        高度: 高度
        字符串: 需要找的字符串（示例：洛阳）
        偏色: RGB偏色设置（示例："ffffff-000000|1c1c1c-000000"）
        相似度: 整个像素矩阵的相似度
        是否开启反向相似度: 是否开启反向相似度
        排序方向类型: 排序类型/方向类型
        水平间距: 字体水平间距（默认11像素）
        垂直间距: 字体垂直间距（默认11像素）
        周围占比: 一个字的周围占比（默认0.1）
        是否独占11: 一个字是否独占11像素（默认True）
        
    Returns:
        返回值代码或成功找到返回MAKEXYWHTO8(fx1, fy1, w, h)
    """
    hd = Config.get_hd()

    func = hd.HCFS_FindStrMutil
    func.restype = ctypes.c_int64
    func.argtypes = [
        ctypes.c_int, ctypes.c_long, ctypes.c_long, ctypes.c_long, ctypes.c_long,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_long,
        ctypes.c_int, ctypes.c_int, ctypes.c_int, ctypes.c_double, ctypes.c_bool
    ]

    return func(
        窗口序号, x, y, 宽度, 高度,
        auto_encode(字符串), auto_encode(偏色), 相似度,
        是否开启反向相似度, 排序方向类型, 水平间距,
        垂直间距, 周围占比, 是否独占11
    )


# INT64  __stdcall HCFS_FindStrMutilsEx(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR str, LPCSTR color_format, double sim, long bfx, int dirType=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_多字符识字Ex(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 字符串: str, 偏色: str, 相似度: float, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    多字符串找(扩展版本) 字库是字符串 例如:洛阳| 北京|广州
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: x坐标
    :param y: y坐标
    :param 宽度: 宽度
    :param 高度: 高度
    :param 字符串: 需要找的字符串 支持多字符串 例如: 大理|无量山|溶洞 "|" 分割
    :param 偏色: 偏色(如: ffffff-000000|1c1c1c-000000) RGB 十六进制 "|" 分割 多点找字
    :param 相似度: 整个像素矩阵的相似度
    :param 是否开启反向相似度: 是否开启反向相似度(开启更精准,但是对于一些小范围的可能会过滤掉,一般开启就行)
    :param 排序方向类型: 排序类型 / 方向类型 排序/方向类型
    :param 水平间距: 字体水平间距 默认11像素
    :param 垂直间距: 字体垂直间距 默认11像素
    :param 周围占比: 一个字的周围占比 默认0.1
    :param 是否独占11: 一个字是否独占11像素 默认真/TRUE/开启
    :return: 返回值代码(查看HD返回值表) 或者 成功找到返回:MAKEXYWHTO8(fx1, fy1, w, h)
    """
    hd = Config.get_hd()

    func = hd.HCFS_FindStrMutilsEx
    func.restype = ctypes.c_int64
    func.argtypes = [
        ctypes.c_int, ctypes.c_long, ctypes.c_long, ctypes.c_long, ctypes.c_long,
        ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_long,
        ctypes.c_int, ctypes.c_int, ctypes.c_int, ctypes.c_double, ctypes.c_bool
    ]

    return func(
        窗口序号, x, y, 宽度, 高度,
        auto_encode(字符串), auto_encode(偏色), 相似度,
        是否开启反向相似度, 排序方向类型, 水平间距,
        垂直间距, 周围占比, 是否独占11
    )


# INT64  __stdcall HCFS_Ocr(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR deltaColor, double sim, long bfx, int dirType=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_Ocr(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 偏色: str, 相似度: float, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    在客户区范围内识别字 字库是字符串或单字 拼接+字符串都支持
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: x坐标
    :param y: y坐标
    :param 宽度: 宽度
    :param 高度: 高度
    :param 偏色: 偏色(如: ffffff-000000|1c1c1c-000000) RGB 十六进制 "|" 分割 多点找字
    :param 相似度: 整个像素矩阵的相似度
    :param 是否开启反向相似度: 是否开启反向相似度(开启更精准,但是对于一些小范围的可能会过滤掉,一般开启就行)
    :param 排序方向类型: 排序类型 / 方向类型 排序/方向类型
    :param 水平间距: 字体水平间距 默认11像素
    :param 垂直间距: 字体垂直间距 默认11像素
    :param 周围占比: 一个字的周围占比 默认0.1
    :param 是否独占11: 一个字是否独占11像素 默认真/TRUE/开启
    :return: 返回值代码(查看HD返回值表) 或者 成功找到返回:MAKEXYWHTO8(fx1, fy1, w, h)
    """
    hd = Config.get_hd()

    func = hd.HCFS_Ocr
    func.restype = ctypes.c_int64
    func.argtypes = [
        ctypes.c_int, ctypes.c_long, ctypes.c_long, ctypes.c_long, ctypes.c_long,
        ctypes.c_char_p, ctypes.c_double, ctypes.c_long,
        ctypes.c_int, ctypes.c_int, ctypes.c_int, ctypes.c_double, ctypes.c_bool
    ]

    return func(
        窗口序号, x, y, 宽度, 高度,
        auto_encode(偏色), 相似度, 是否开启反向相似度,
        排序方向类型, 水平间距, 垂直间距,
        周围占比, 是否独占11
    )


# INT64  __stdcall HCFS_OcrByFile(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR color_format, double sim, LPCSTR iamgeName, int bfx, int dirType=0, int spaceH=11, int spaceV=11, double groundRate=0.1, BOOL bOne11=TRUE);
def HD识字_Ocr从文件(窗口序号: int, x: int, y: int, 宽度: int, 高度: int, 偏色: str, 相似度: float, 图片名字: str, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    在客户区范围内识别字(原图从文件) 字库是字符串或单字 拼接+字符串都支持
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: x坐标
    :param y: y坐标
    :param 宽度: 宽度
    :param 高度: 高度
    :param 偏色: 偏色(如: ffffff-000000|1c1c1c-000000) RGB 十六进制 "|" 分割 多点找字
    :param 相似度: 整个像素矩阵的相似度
    :param 图片名字: 指定一张识字的图片文件(.bmp),支持加路径,不加路径则在全局路径找,图片后缀不要省略(支持绝对路径和相对路径)
    :param 是否开启反向相似度: 是否开启反向相似度(开启更精准,但是对于一些小范围的可能会过滤掉,一般开启就行)
    :param 排序方向类型: 排序类型 / 方向类型 排序/方向类型
    :param 水平间距: 字体水平间距 默认11像素
    :param 垂直间距: 字体垂直间距 默认11像素
    :param 周围占比: 一个字的周围占比 默认0.1
    :param 是否独占11: 一个字是否独占11像素 默认真/TRUE/开启
    :return: 返回值代码(查看HD返回值表) 或者 json格式的识字结果
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HCFS_OcrByFile = hd.HCFS_OcrByFile
    HCFS_OcrByFile.restype = ctypes.c_int64
    HCFS_OcrByFile.argtypes = [
        ctypes.c_int32,  # 窗口序号
        ctypes.c_long,   # x
        ctypes.c_long,   # y
        ctypes.c_long,   # 宽度
        ctypes.c_long,   # 高度
        ctypes.c_char_p, # 偏色
        ctypes.c_double, # 相似度
        ctypes.c_char_p, # 图片名字
        ctypes.c_int32,  # 是否开启反向相似度
        ctypes.c_int32,  # 排序方向类型
        ctypes.c_int32,  # 水平间距
        ctypes.c_int32,  # 垂直间距
        ctypes.c_double, # 周围占比
        ctypes.c_bool    # 是否独占11
    ]

    # 将偏色和图片名字转换为字节串
    偏色_bytes = auto_encode(偏色)
    图片名字_bytes = auto_encode(图片名字)

    # 调用C函数
    ret = HCFS_OcrByFile(
        ctypes.c_int32(窗口序号),
        ctypes.c_long(x),
        ctypes.c_long(y),
        ctypes.c_long(宽度),
        ctypes.c_long(高度),
        ctypes.c_char_p(偏色_bytes),
        ctypes.c_double(相似度),
        ctypes.c_char_p(图片名字_bytes),
        ctypes.c_int32(是否开启反向相似度),
        ctypes.c_int32(排序方向类型),
        ctypes.c_int32(水平间距),
        ctypes.c_int32(垂直间距),
        ctypes.c_double(周围占比),
        ctypes.c_bool(是否独占11)
    )
    return ret


# INT64  __stdcall HCFS_OcrByMem(int 窗口序号, long findX, long findY, long findW, long findH, LPCSTR color_format, double sim, BYTE* data, int dataSize, int bfx, int dirType= 0 , int spaceH = 11, int spaceV = 11, double groundRate = 0.1, BOOL bOne11= TRUE);
def HD识字_Ocr从内存(窗口序号: int, x: int, y: int, w: int, h: int, 偏色: str, 相似度: float, 图片数据: bytes, 图片数据大小: int, 是否开启反向相似度: int, 排序方向类型: int = 0, 水平间距: int = 11, 垂直间距: int = 11, 周围占比: float = 0.1, 是否独占11: bool = True) -> int:
    """
    在客户区范围内识别字(原图从内存) 字库是字符串或单字 拼接+字符串都支持
    :param 窗口序号: 窗口序号 (从1开始)
    :param x: 起始X坐标
    :param y: 起始Y坐标
    :param w: 宽度
    :param h: 高度
    :param 偏色: 偏色 (例如: ffffff-000000|1c1c1c-000000)
    :param 相似度: 整个像素矩阵的相似度
    :param 图片数据: 图片数据的二进制内存首地址 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
    :param 图片数据大小: 图片数据大小
    :param 是否开启反向相似度: 是否开启反向相似度 (开启更精准)
    :param 排序方向类型: 排序类型/方向类型 (默认0)
    :param 水平间距: 字体水平间距 (默认11像素)
    :param 垂直间距: 字体垂直间距 (默认11像素)
    :param 周围占比: 一个字的周围占比 (默认0.1)
    :param 是否独占11: 一个字是否独占11像素 (默认True)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HCFS_OcrByMem = hd.HCFS_OcrByMem
    HCFS_OcrByMem.restype = ctypes.c_int64
    HCFS_OcrByMem.argtypes = [
        ctypes.c_int32,       # 窗口序号
        ctypes.c_long,        # x
        ctypes.c_long,        # y
        ctypes.c_long,        # w
        ctypes.c_long,        # h
        ctypes.c_char_p,      # 偏色
        ctypes.c_double,      # 相似度
        ctypes.POINTER(ctypes.c_ubyte),  # 图片数据
        ctypes.c_int32,       # 图片数据大小
        ctypes.c_int32,       # 是否开启反向相似度
        ctypes.c_int32,       # 排序方向类型
        ctypes.c_int32,       # 水平间距
        ctypes.c_int32,       # 垂直间距
        ctypes.c_double,      # 周围占比
        ctypes.c_bool         # 是否独占11
    ]

    # 将偏色转换为字节串
    color_bytes = auto_encode(偏色)

    # 调用C函数
    ret = HCFS_OcrByMem(
        ctypes.c_int32(窗口序号),
        ctypes.c_long(x),
        ctypes.c_long(y),
        ctypes.c_long(w),
        ctypes.c_long(h),
        color_bytes,
        ctypes.c_double(相似度),
        图片数据,
        ctypes.c_int32(图片数据大小),
        ctypes.c_int32(是否开启反向相似度),
        ctypes.c_int32(排序方向类型),
        ctypes.c_int32(水平间距),
        ctypes.c_int32(垂直间距),
        ctypes.c_double(周围占比),
        ctypes.c_bool(是否独占11)
    )

    return ret


# INT64  __stdcall HCFS_SetCharSpaceHV(int lenH = 11, int lenV = 11);
def HD识字_设置水平垂直间距(水平间距: int = 11, 垂直间距: int = 11) -> int:
    """
    设置间距 (在识别拼接字和OCR中尤其重要)
    :param 水平间距: 水平方向的间距 (默认11像素)
    :param 垂直间距: 垂直方向的间距 (默认11像素)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HCFS_SetCharSpaceHV = hd.HCFS_SetCharSpaceHV
    HCFS_SetCharSpaceHV.restype = ctypes.c_int64
    HCFS_SetCharSpaceHV.argtypes = [
        ctypes.c_int32,  # 水平间距
        ctypes.c_int32   # 垂直间距
    ]

    # 调用C函数
    ret = HCFS_SetCharSpaceHV(
        ctypes.c_int32(水平间距),
        ctypes.c_int32(垂直间距)
    )

    return ret

# INT64  __stdcall HCFS_IsOne11(BOOL b = TRUE);
def HD识字_设置11(是否独占11: bool = True) -> int:
    """
    设置11行中(同宽)矩形内,是否只有一个字
    :param 是否独占11: 是否独占11像素 (默认True)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HCFS_IsOne11 = hd.HCFS_IsOne11
    HCFS_IsOne11.restype = ctypes.c_int64
    HCFS_IsOne11.argtypes = [
        ctypes.c_bool  # 是否独占11
    ]

    # 调用C函数
    ret = HCFS_IsOne11(
        ctypes.c_bool(是否独占11)
    )

    return ret

# double  __stdcall HCFS_GroundRate(double rate = 0.1);
def HD识字_设置周围占比(周围占比: float = 0.1) -> int:
    """
    设置字周围一个像素 上下左右的像素占比
    :param 周围占比: 一个字的周围占比 (默认0.1)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HCFS_GroundRate = hd.HCFS_GroundRate
    HCFS_GroundRate.restype = ctypes.c_double
    HCFS_GroundRate.argtypes = [
        ctypes.c_double  # 周围占比
    ]

    # 调用C函数
    ret = HCFS_GroundRate(
        ctypes.c_double(周围占比)
    )

    return ret


from .config import Config, ctypes
from .config import auto_encode

# 状态机回调类型定义
HCMTStatusFunType = ctypes.WINFUNCTYPE(ctypes.c_int64, ctypes.c_int32, ctypes.c_int64)

# INT64 __stdcall HCMT_DelayEx(int mis, BOOL bStatus);
def HD状态机_延迟Ex(毫秒: int, 是否状态机回调: bool = False) -> int:
    """
    延迟扩展版
    
    Args:
        毫秒: 毫秒延迟
        是否状态机回调: 是否状态机回调，默认为False，如果在状态机回调中调用，请置为True
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCMT_DelayEx = hd.HCMT_DelayEx
    HCMT_DelayEx.restype = ctypes.c_int64
    HCMT_DelayEx.argtypes = [
        ctypes.c_int32,
        ctypes.c_bool
    ]
    
    ret = HCMT_DelayEx(ctypes.c_int32(毫秒), ctypes.c_bool(是否状态机回调))
    return ret

# INT64 __stdcall HCMT_StartStatus();
def HD状态机_开启状态机() -> int:
    """
    开启状态机
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCMT_StartStatus = hd.HCMT_StartStatus
    HCMT_StartStatus.restype = ctypes.c_int64
    HCMT_StartStatus.argtypes = []
    
    ret = HCMT_StartStatus()
    return ret

# INT64 __stdcall HCMT_AddStatus(INT64 funCallBack, INT64 lparam, BOOL bEnable, int statusType);
def HD状态机_添加状态机状态(状态回调: HCMTStatusFunType, 额外参数: int, 是否有效: bool, 状态值: int) -> int:
    """
    添加状态机状态
    
    Args:
        状态回调: 状态回调函数，例如：
            def callback_function(windowsIndex, lparam):
                print(f"Callback called with windowsIndex={windowsIndex}, lparam={lparam}")
                return 0  # 返回值类型为__int64
        额外参数: 额外参数，可以传递指针或者8字节数据，这个用户自定义参数会在触发回调的时候传递给回调的第二个形参
        是否有效: 状态是否有效，无效是不会触发状态回调的，即便是检索到这个状态的时候，也不会触发回调，只会不停判断
        状态值: 状态值，自定义值（内置：-1表示无状态，不要重复指定），大小决定优先级
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCMT_AddStatus = hd.HCMT_AddStatus
    HCMT_AddStatus.restype = ctypes.c_int64
    HCMT_AddStatus.argtypes = [
        ctypes.c_int64,
        ctypes.c_int64,
        ctypes.c_bool,
        ctypes.c_int32
    ]
    
    heartFun = HCMTStatusFunType(状态回调)
    
    ret = HCMT_AddStatus(
        ctypes.cast(heartFun, ctypes.c_void_p).value,
        ctypes.c_int64(额外参数),
        ctypes.c_bool(是否有效),
        ctypes.c_int32(状态值)
    )
    return ret

# INT64 __stdcall HCMT_EnableStatus(int statusType, BOOL bEnable);
def HD状态机_操作状态(状态值: int, 是否有效: bool) -> int:
    """
    操作状态
    
    Args:
        状态值: 自定义的状态值
        是否有效: 是否有效
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCMT_EnableStatus = hd.HCMT_EnableStatus
    HCMT_EnableStatus.restype = ctypes.c_int64
    HCMT_EnableStatus.argtypes = [
        ctypes.c_int32,
        ctypes.c_bool
    ]
    
    ret = HCMT_EnableStatus(ctypes.c_int32(状态值), ctypes.c_bool(是否有效))
    return ret

# INT64 __stdcall HCMT_ChangeStatus(int statusType);
def HD状态机_改变当前状态(状态值: int) -> int:
    """
    改变当前状态
    
    Args:
        状态值: 自定义的状态值
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCMT_ChangeStatus = hd.HCMT_ChangeStatus
    HCMT_ChangeStatus.restype = ctypes.c_int64
    HCMT_ChangeStatus.argtypes = [
        ctypes.c_int32
    ]
    
    ret = HCMT_ChangeStatus(ctypes.c_int32(状态值))
    return ret

# INT64 __stdcall HCMT_RetraceStatus(BOOL bClear);
def HD状态机_回溯上个状态(是否清除: bool = False) -> int:
    """
    回溯上个状态
    
    Args:
        是否清除: True表示清除之前的栈缓存同时改变当前状态位-1（空），False表示清除当前栈顶的状态，相同的全部删除，同时改变当前状态为清除后的栈顶的那个状态
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCMT_RetraceStatus = hd.HCMT_RetraceStatus
    HCMT_RetraceStatus.restype = ctypes.c_int64
    HCMT_RetraceStatus.argtypes = [
        ctypes.c_bool
    ]
    
    ret = HCMT_RetraceStatus(ctypes.c_bool(是否清除))
    return ret

# INT64 __stdcall HCMT_IsStatus();
def HD状态机_是否状态中() -> int:
    """
    当前状态机的状态在回调中是否有效
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCMT_IsStatus = hd.HCMT_IsStatus
    HCMT_IsStatus.restype = ctypes.c_int64
    HCMT_IsStatus.argtypes = []
    
    ret = HCMT_IsStatus()
    return ret

# INT64 __stdcall HCMT_StatusSleep(int mis);
def HD状态机_状态延迟(毫秒: int) -> int:
    """
    状态延迟
    
    Args:
        毫秒: 毫秒延迟
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCMT_StatusSleep = hd.HCMT_StatusSleep
    HCMT_StatusSleep.restype = ctypes.c_int64
    HCMT_StatusSleep.argtypes = [
        ctypes.c_int32
    ]
    
    ret = HCMT_StatusSleep(ctypes.c_int32(毫秒))
    return ret

# INT64 __stdcall HCMT_GetStatus(int windowsIndex);
def HD状态机_获取当前状态(窗口索引: int) -> int:
    """
    获取当前状态
    
    Args:
        窗口索引: 窗口索引
    
    Returns:
        int: 当前状态值
    """
    hd = Config.get_hd()
    
    HCMT_GetStatus = hd.HCMT_GetStatus
    HCMT_GetStatus.restype = ctypes.c_int64
    HCMT_GetStatus.argtypes = [
        ctypes.c_int32
    ]
    
    ret = HCMT_GetStatus(ctypes.c_int32(窗口索引))
    return ret


from .config import Config, ctypes
from .config import auto_encode

# void __stdcall HCRES_SetResPathA(char * path);
def HD资源_设置路径A(路径: str) -> None:
    """
    设置ANSI编码资源路径
    :param 路径: ANSI编码路径字符串(自动转换为本地编码)
    :return: None
    """
    hd = Config.get_hd()

    HCRES_SetResPathA = hd.HCRES_SetResPathA
    HCRES_SetResPathA.restype = None
    HCRES_SetResPathA.argtypes = [ctypes.c_char_p]

    # 使用auto_encode自动转换编码
    path_bytes = auto_encode(路径)

    HCRES_SetResPathA(path_bytes)


# void __stdcall HCRES_SetResPathW(wchar_t * path);
def HD资源_设置路径W(路径: str) -> None:
    """
    设置Unicode资源路径(Windows原生宽字符)
    :param 路径: Unicode路径字符串
    :return: None
    """
    hd = Config.get_hd()

    HCRES_SetResPathW = hd.HCRES_SetResPathW
    HCRES_SetResPathW.restype = None
    HCRES_SetResPathW.argtypes = [ctypes.c_wchar_p]

    # 直接传递Python字符串，ctypes自动转换宽字符
    HCRES_SetResPathW(ctypes.c_wchar_p(路径))

# void __stdcall  HCRES_SetResPathEx(__int32 windIndex, char * path);
def HD资源_设置路径Ex(窗口序号: int, 路径: str) -> None:
    """
    设置ANSI编码资源路径Ex
    :param 窗口序号: 窗口序号
    :param 路径: ANSI编码路径字符串(自动转换为本地编码)
    :return: None
    """
    hd = Config.get_hd()

    HCRES_SetResPathEx = hd.HCRES_SetResPathEx
    HCRES_SetResPathEx.restype = None
    HCRES_SetResPathEx.argtypes = [ctypes.c_int32,ctypes.c_char_p]

    # 使用auto_encode自动转换编码
    path_bytes = auto_encode(路径)

    HCRES_SetResPathEx(ctypes.c_int32(窗口序号),path_bytes)


from .config import Config, ctypes
from .config import auto_encode


#   Int64 __stdcall HDDW_Open(__int32 windIndex,__int64 attachHwnd);
def HD实时绘制_打开(windIndex: int,attachHwnd:int) -> int:
    """
    打开实时绘制

    Args:
        windIndex:窗口序号
        attachHwnd:附加窗口句柄
    Returns:
        int: 返回值代码（查看HD返回值表）

    Note:
        无
    """
    hd = Config.get_hd()

    HDDW_Open = hd.HDDW_Open
    HDDW_Open.restype = ctypes.c_int64
    HDDW_Open.argtypes = [
        ctypes.c_int32,
        ctypes.c_int64
    ]

    ret = HDDW_Open(ctypes.c_int32(windIndex),ctypes.c_int64(attachHwnd))
    return ret


#   Int64 __stdcall HDDW_Close(__int32 windIndex);
def HD实时绘制_关闭(windIndex: int) -> int:
    """
    关闭实时绘制

    Args:
        windIndex:窗口序号
    Returns:
        int: 返回值代码（查看HD返回值表）

    Note:
        无
    """
    hd = Config.get_hd()

    HDDW_Close = hd.HDDW_Close
    HDDW_Close.restype = ctypes.c_int64
    HDDW_Close.argtypes = [
        ctypes.c_int32
    ]

    ret = HDDW_Close(ctypes.c_int32(windIndex))
    return ret


#   Int64 __stdcall HDDW_SetSetting(BOOL bRDraw, BOOL bYoloDraw, BOOL bMKBDraw, __int32 updateTime, char* lparam = NULL);
def HD实时绘制_设置配置(bRDraw: bool= True,bYoloDraw: bool= True,bMKBDraw: bool = True,updateTime: int = 100,lparam: str = None) -> int:
    """
    设置配置实时绘制配置信息

    Args:
        bRDraw:是否绘制识别信息
        bYoloDraw:是否绘制yolov信息
        bMKBDraw:是否绘制键鼠信息
        updateTime:每次更新间隔时间(毫秒)
        param:额外json配置信息 一般NULL 使用的内置配置
        json配置:
        {"bgc":0xFFFFFFFF} 窗口背景色包含透明度 RGBA() 后续绘增加更多的配置属性
    Returns:
        int: 返回值代码（查看HD返回值表）

    Note:
        无
    """
    hd = Config.get_hd()

    HDDW_SetSetting = hd.HDDW_SetSetting
    HDDW_SetSetting.restype = ctypes.c_int64
    HDDW_SetSetting.argtypes = [
        ctypes.c_bool,
        ctypes.c_bool,
        ctypes.c_bool,
        ctypes.c_int32,
        ctypes.c_char_p,
    ]

    ret = HDDW_SetSetting(
        ctypes.c_bool(bRDraw),
        ctypes.c_bool(bYoloDraw),
        ctypes.c_bool(bMKBDraw),
        ctypes.c_int32(updateTime),
        (auto_encode(lparam) if lparam else None)
    )
    return ret


from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCEnv_GetMaxWindowNum();
def HD环境_获取最大多开数() -> int:
    """
    获取最大多开数
    
    Returns:
        int: 最大多开数，窗口序号不能大于等于这个返回值同时也不能小于0
    """
    hd = Config.get_hd()
    
    HCEnv_GetMaxWindowNum = hd.HCEnv_GetMaxWindowNum
    HCEnv_GetMaxWindowNum.restype = ctypes.c_int64
    HCEnv_GetMaxWindowNum.argtypes = []
    
    ret = HCEnv_GetMaxWindowNum()
    return ret

# INT64 __stdcall HCEnv_GetWinExIndex(int winIndex);
def HD环境_获取副窗口序号(窗口序号: int) -> int:
    """
    获取副窗口序号
    
    Args:
        窗口序号: 传递窗口序号，返回一个与当前指定的窗口序号的一个副窗口序号
    
    Returns:
        int: 副窗口序号，这个副窗口序号可以用于登录器的绑定和操作，相当于窗口序号的一个助手，做一些额外的事情，相当于一个窗口序号可以操作2个进程。如：窗口序号1，那么他返回的窗口扩展序号就是1+31也就是32序号
    """
    hd = Config.get_hd()
    
    HCEnv_GetWinExIndex = hd.HCEnv_GetWinExIndex
    HCEnv_GetWinExIndex.restype = ctypes.c_int64
    HCEnv_GetWinExIndex.argtypes = [
        ctypes.c_int32
    ]
    
    ret = HCEnv_GetWinExIndex(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCEnv_GetGlobalWinExIndex();
def HD环境_全局副窗口序号() -> int:
    """
    获取全局副窗口序号，这是一个全局的序号
    
    Returns:
        int: 全局副窗口序号，一个中控仅有一个，计算方式：0+31也就是这个全局序号为31，序号从0开始。用途：给当前中控分配一个助手，来控制一个进程来辅助中控做一些事情
    """
    hd = Config.get_hd()
    
    HCEnv_GetGlobalWinExIndex = hd.HCEnv_GetGlobalWinExIndex
    HCEnv_GetGlobalWinExIndex.restype = ctypes.c_int64
    HCEnv_GetGlobalWinExIndex.argtypes = []
    
    ret = HCEnv_GetGlobalWinExIndex()
    return ret

# INT64 __stdcall HCEnv_Init(int timeOut);
def HD环境_初始化(通讯超时时间: int = 10000) -> int:
    """
    HD插件环境加载，登录后，必须再次调用此接口，进程中控环境的初始化，否则无法使用其他接口
    
    Args:
        通讯超时时间: 通讯超时毫秒
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCEnv_Init = hd.HCEnv_Init
    HCEnv_Init.restype = ctypes.c_int64
    HCEnv_Init.argtypes = [
        ctypes.c_int32
    ]
    
    ret = HCEnv_Init(ctypes.c_int32(通讯超时时间))
    return ret

# INT64 __stdcall HCEnv_InitEx(int 通讯超时毫秒, int 通讯检测间隔毫秒, int 回调响应毫秒);
def HD环境_初始化Ex(通讯超时毫秒: int = 10000, 通讯检测间隔毫秒: int = 20, 回调响应毫秒: int = 5) -> int:
    """
    HD插件环境加载扩展版本，登录后，必须再次调用此接口，进程中控环境的初始化，否则无法使用其他接口
    
    Args:
        通讯超时毫秒: 通讯超时毫秒
        通讯检测间隔毫秒: 通讯检测间隔毫秒
        回调响应毫秒: 回调响应毫秒
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCEnv_InitEx = hd.HCEnv_InitEx
    HCEnv_InitEx.restype = ctypes.c_int64
    HCEnv_InitEx.argtypes = [
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32
    ]
    
    ret = HCEnv_InitEx(
        ctypes.c_int32(通讯超时毫秒),
        ctypes.c_int32(通讯检测间隔毫秒),
        ctypes.c_int32(回调响应毫秒)
    )
    return ret

# INT64 __stdcall HCEnv_Load(int 窗口序号, int 目标进程PID, int 游戏类型);
def HD环境_加载窗口(窗口序号: int, 目标进程PID: int, 游戏类型: int = 0) -> int:
    """
    HD插件环境加载
    
    Args:
        窗口序号: 窗口序号，从1开始
        目标进程PID: 目标进程PID
        游戏类型: 内置了游戏接口，每个游戏类型值不同，可以在工具上查看对应的值
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCEnv_Load = hd.HCEnv_Load
    HCEnv_Load.restype = ctypes.c_int64
    HCEnv_Load.argtypes = [
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32
    ]
    
    ret = HCEnv_Load(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(目标进程PID),
        ctypes.c_int32(游戏类型)
    )
    return ret

# INT64 __stdcall HCEnv_LoadEx(int 窗口序号, int 目标进程PID, int 游戏类型, BOOL 是否响应回调);
def HD环境_加载窗口Ex(窗口序号: int, 目标进程PID: int, 游戏类型: int = 0, 是否响应回调: bool = False) -> int:
    """
    HD插件环境加载扩展版本，涉及到回调
    
    Args:
        窗口序号: 窗口序号，从1开始
        目标进程PID: 目标进程PID
        游戏类型: 内置了游戏接口，每个游戏类型值不同，可以在工具上查看对应的值
        是否响应回调: 是否响应回调，如果需要开启跨进程回调（如：send sendto recv recvfrom，心跳等内置插件设置的回调触发），请开启
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCEnv_LoadEx = hd.HCEnv_LoadEx
    HCEnv_LoadEx.restype = ctypes.c_int64
    HCEnv_LoadEx.argtypes = [
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_bool
    ]
    
    ret = HCEnv_LoadEx(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(目标进程PID),
        ctypes.c_int32(游戏类型),
        ctypes.c_bool(是否响应回调)
    )
    return ret

# INT64 __stdcall HCEnv_UnLoad(int 窗口序号);
def HD环境_卸载窗口(窗口序号: int) -> int:
    """
    HD插件环境卸载
    
    Args:
        窗口序号: 窗口序号，从1开始
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCEnv_UnLoad = hd.HCEnv_UnLoad
    HCEnv_UnLoad.restype = ctypes.c_int64
    HCEnv_UnLoad.argtypes = [
        ctypes.c_int32
    ]
    
    ret = HCEnv_UnLoad(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCEnv_UnLoadEx(int 窗口序号, BOOL bRecon);
def HD环境_卸载窗口Ex(窗口序号: int, 是否需要重连: bool = True) -> int:
    """
    HD插件环境卸载扩展版本
    
    Args:
        窗口序号: 窗口序号，从1开始
        是否需要重连: 是否还需要重连，默认是需要重连
    
    Returns:
        int: 返回值代码
    
    Note:
        调用这个接口需要先调用环境初始化模块中的初始化接口
        进程关闭一定要记得卸载窗口序号对应的窗口环境，以便于下次窗口序号使用
        1.没安装过插件的都不算重连窗口，全部当新窗口处理
        2.安装过插件的不管卸载环境还是崩溃或者重启窗口都可以重连窗口，一个序号只能绑定到一个窗口操作
    """
    hd = Config.get_hd()
    
    HCEnv_UnLoadEx = hd.HCEnv_UnLoadEx
    HCEnv_UnLoadEx.restype = ctypes.c_int64
    HCEnv_UnLoadEx.argtypes = [
        ctypes.c_int32,
        ctypes.c_bool
    ]
    
    ret = HCEnv_UnLoadEx(ctypes.c_int32(窗口序号), ctypes.c_bool(是否需要重连))
    return ret

# HD心跳回调 stdcall回调类型
# __int32(*HeartFunType)(__int32 窗口索引, __int32 type);
HD_HeartFunType_stdcall = ctypes.WINFUNCTYPE(ctypes.c_int32, ctypes.c_int32, ctypes.c_int32)

# INT64 __stdcall HCEnv_AttachHeart(int type, INT64 funCallbackAddr, int timeOutNor, int timeOut);
def HD环境_附加心跳(检测类型: int, 回调函数: HD_HeartFunType_stdcall = None, 正常心跳间隔: int = 10000, 检测超时: int = 10000) -> int:
    """
    给中控附加心跳
    
    Args:
        检测类型: 0->正常心跳（内部触发心跳回调+排序回调），1->通讯线程，2->主线程，3->卡屏，6->1+2+3
        回调函数: 当出现卡住或者掉线会触发相应的回调函数，并传递2个参数分别是->窗口索引和事件类型
        正常心跳间隔: 正常心跳间隔时间，超过此时间未检查到异常则触发正常心跳
        检测超时: 检测超时，超过此时间未发现改变则判定为卡住或掉线
    
    Returns:
        int: 返回值代码
    
    Note:
        检测主线程心跳需先HOOK主线程接口HC_HookMainThread
        回调函数返回值：1正常处理返回，0禁止当前窗口序号的心跳（永久无法恢复除非重启中控）
    """
    hd = Config.get_hd()
    
    HCEnv_AttachHeart = hd.HCEnv_AttachHeart
    HCEnv_AttachHeart.restype = ctypes.c_int64
    HCEnv_AttachHeart.argtypes = [
        ctypes.c_int32,
        ctypes.c_int64,
        ctypes.c_int32,
        ctypes.c_int32
    ]
    
    funCallback_ptr = ctypes.c_int64(ctypes.cast(HD_HeartFunType_stdcall(回调函数), ctypes.c_void_p).value) if 回调函数 else ctypes.c_int64(0)
    
    ret = HCEnv_AttachHeart(
        ctypes.c_int32(检测类型),
        funCallback_ptr,
        ctypes.c_int32(正常心跳间隔),
        ctypes.c_int32(检测超时)
    )
    return ret

# INT64 __stdcall HCEnv_SetScreenCheckHeart(int x, int y, int w, int h, int 最大次数, int 截屏前后间隔时间);
def HD环境_设置卡屏检查信息(客户端X坐标: int, 客户端Y坐标: int, 客户端宽度: int, 客户端高度: int, 检查次数: int, 截屏前后间隔时间: int = 1000) -> int:
    """
    当我们心跳检测指定了3或者6需要设置卡屏范围和卡屏检测次数，当大于这个次数就调用回调
    
    Args:
        客户端X坐标: 客户端X坐标
        客户端Y坐标: 客户端Y坐标
        客户端宽度: 客户端宽度
        客户端高度: 客户端高度
        检查次数: 检查次数
        截屏前后间隔时间: 检查间隔时间毫秒
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCEnv_SetScreenCheckHeart = hd.HCEnv_SetScreenCheckHeart
    HCEnv_SetScreenCheckHeart.restype = ctypes.c_int64
    HCEnv_SetScreenCheckHeart.argtypes = [
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32
    ]
    
    ret = HCEnv_SetScreenCheckHeart(
        ctypes.c_int32(客户端X坐标),
        ctypes.c_int32(客户端Y坐标),
        ctypes.c_int32(客户端宽度),
        ctypes.c_int32(客户端高度),
        ctypes.c_int32(检查次数),
        ctypes.c_int32(截屏前后间隔时间)
    )
    return ret

# INT64 __stdcall HCEnv_DetachHeart();
def HD环境_脱离心跳() -> int:
    """
    脱离中控附加的心跳检测
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCEnv_DetachHeart = hd.HCEnv_DetachHeart
    HCEnv_DetachHeart.restype = ctypes.c_int64
    HCEnv_DetachHeart.argtypes = []
    
    ret = HCEnv_DetachHeart()
    return ret

# INT64 __stdcall HCEnv_Debug(BOOL 是否调试);
def HD环境_调试模式(是否调试: bool = False) -> int:
    """
    设置导入接口为调试模式
    
    Args:
        是否调试: 当使用HDDebug.dll导入接口的时候就需要调用这个设置为调试模式（否则插件安装不成功）然后方可继续后面的一系列操作
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCEnv_Debug = hd.HCEnv_Debug
    HCEnv_Debug.restype = ctypes.c_int64
    HCEnv_Debug.argtypes = [
        ctypes.c_bool
    ]
    
    ret = HCEnv_Debug(ctypes.c_bool(是否调试))
    return ret


# INT64  __stdcall  HCEnv_MsgFile(BOOL 是否文件提示 = TRUE);
def HD环境_开启文件提示(是否开启文件提示: bool = True) -> int:
    """
   设置是否打开文件提示窗口
    Args:
        是否文件提示:是否开启文件提示日志
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()

    HCEnv_MsgFile = hd.HCEnv_MsgFile
    HCEnv_MsgFile.restype = ctypes.c_int64
    HCEnv_MsgFile.argtypes = [
        ctypes.c_bool
    ]

    ret = HCEnv_MsgFile(ctypes.c_bool(是否开启文件提示))
    return ret


# __int64 __stdcall  HCEnv_GetExcuteEnvInfo(__int32 窗口序号);
def HD环境_获取插件执行环境信息(窗口序号: int) -> int:
    """
   获取通讯插件所绑定的目标进程的执行线程环境信息
   通过HCEnv_GetRetJson返回字符串格式:序号-进程ID:进程ID,窗口序号,线程ID,执行状态|进程ID,窗口序号,线程ID,执行状态|进程ID,窗口序号,线程ID,执行状态 | ....
    Args:
        窗口序号:窗口序号 （从1开始）
    Returns:
        查看返回值表HD返回值表

    """

    hd = Config.get_hd()

    HCEnv_GetExcuteEnvInfo = hd.HCEnv_GetExcuteEnvInfo
    HCEnv_GetExcuteEnvInfo.restype = ctypes.c_int64
    HCEnv_GetExcuteEnvInfo.argtypes = [
        ctypes.c_int32
    ]

    ret = HCEnv_GetExcuteEnvInfo(ctypes.c_int32(窗口序号))
    return ret


# __int64 __stdcall HCEnv_ExitProcess(__int32 窗口序号);
def HD环境_关闭绑定进程(窗口序号: int) -> int:
    """
   关闭绑定进程
   内部实现可能是正常关闭也可能是强制关闭 至于是哪一种会根据实际情况动态调用
    Args:
        窗口序号:窗口序号 （从1开始）
    Returns:
        查看返回值表HD返回值表

    """

    hd = Config.get_hd()

    HCEnv_ExitProcess = hd.HCEnv_ExitProcess
    HCEnv_ExitProcess.restype = ctypes.c_int64
    HCEnv_ExitProcess.argtypes = [
        ctypes.c_int32
    ]

    ret = HCEnv_ExitProcess(ctypes.c_int32(窗口序号))
    return ret

# __int64 __stdcall  HCEnv_ProtectFun(__int64 funAddr,__int32 offset,__int32 size);
def HD环境_保护函数(funAddr,offset,size) -> int:
    """
   添加安全函数
    Args:
        int64 funAddr:函数地址
        int offset:基于函数地址+偏移
        int size:从(函数地址+偏移) 开始保护多少字节 最大字节数不得超过1024
    Returns:
        是否添加成功

    """
    funCallback_ptr = ctypes.c_int64(ctypes.cast(funAddr, ctypes.c_void_p).value) if funAddr else ctypes.c_int64(0)

    hd = Config.get_hd()

    HCEnv_ProtectFun = hd.HCEnv_ProtectFun
    HCEnv_ProtectFun.restype = ctypes.c_int64
    HCEnv_ProtectFun.argtypes = [
        ctypes.c_int64,
        ctypes.c_int32,
        ctypes.c_int32
    ]

    ret = HCEnv_ProtectFun(funCallback_ptr,ctypes.c_int32(offset),ctypes.c_int32(size))
    return ret

# INT64 __stdcall HCEnv_AddThread(int 窗口序号, int 线程ID, int bDebug);
def HD环境_添加线程(窗口序号: int, 线程ID: int, 是否是调试模式: int = 0) -> int:
    """
    添加线程环境
    
    Args:
        窗口序号: 窗口序号，从1开始
        线程ID: 当前线程ID
        是否是调试模式: 是否是调试模式，如果是那么线程ID可以任意指定
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCEnv_AddThread = hd.HCEnv_AddThread
    HCEnv_AddThread.restype = ctypes.c_int64
    HCEnv_AddThread.argtypes = [
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32
    ]
    
    ret = HCEnv_AddThread(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(线程ID),
        ctypes.c_int32(是否是调试模式)
    )
    return ret

# INT64 __stdcall HCEnv_TestCALL_RetValue(int 窗口序号, INT64 rcx = 0, INT64 rdx = 0, INT64 r8 = 0, INT64 r9 = 0, INT64 lparam5 = 0, INT64 lparam6 = 0, BOOL 是否主线程调用 = FALSE);
def HD环境_测试通讯值(窗口序号: int, rcx: int = 0, rdx: int = 0, r8: int = 0, r9: int = 0, lparam5: int = 0, lparam6: int = 0, 是否主线程调用: bool = False) -> int:
    """
    测试是否通讯成功,返回单一值
    :param 窗口序号: 窗口序号 (从1开始)
    :param rcx: rcx
    :param rdx: rdx
    :param r8: r8
    :param r9: r9
    :param lparam5: lparam5
    :param lparam6: lparam6
    :param 是否主线程调用: 是否主线程调用
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HCEnv_TestCALL_RetValue = hd.HCEnv_TestCALL_RetValue
    HCEnv_TestCALL_RetValue.restype = ctypes.c_int64
    HCEnv_TestCALL_RetValue.argtypes = [
        ctypes.c_int32,  # 窗口序号
        ctypes.c_int64,  # rcx
        ctypes.c_int64,  # rdx
        ctypes.c_int64,  # r8
        ctypes.c_int64,  # r9
        ctypes.c_int64,  # lparam5
        ctypes.c_int64,  # lparam6
        ctypes.c_bool    # 是否主线程调用
    ]

    # 调用C函数
    ret = HCEnv_TestCALL_RetValue(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(rcx),
        ctypes.c_int64(rdx),
        ctypes.c_int64(r8),
        ctypes.c_int64(r9),
        ctypes.c_int64(lparam5),
        ctypes.c_int64(lparam6),
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCEnv_TestCALL_RetArrayEx(int 窗口序号, int 线程ID, INT64 rcx = 0, INT64 rdx = 0, INT64 r8 = 0, INT64 r9 = 0, INT64 lparam5 = 0, INT64 lparam6 = 0, BOOL 是否主线程调用 = FALSE);
def HD环境_测试通讯字符串Ex(窗口序号: int, 线程ID: int, rcx: int = 0, rdx: int = 0, r8: int = 0, r9: int = 0, lparam5: int = 0, lparam6: int = 0, 是否主线程调用: bool = False) -> int:
    """
    测试是否通讯成功(扩展版本),返回json字符串
    :param 窗口序号: 窗口序号 (从1开始)
    :param 线程ID: 线程ID
    :param rcx: rcx
    :param rdx: rdx
    :param r8: r8
    :param r9: r9
    :param lparam5: lparam5
    :param lparam6: lparam6
    :param 是否主线程调用: 是否主线程调用
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HCEnv_TestCALL_RetArrayEx = hd.HCEnv_TestCALL_RetArrayEx
    HCEnv_TestCALL_RetArrayEx.restype = ctypes.c_int64
    HCEnv_TestCALL_RetArrayEx.argtypes = [
        ctypes.c_int32,  # 窗口序号
        ctypes.c_int32,  # 线程ID
        ctypes.c_int64,  # rcx
        ctypes.c_int64,  # rdx
        ctypes.c_int64,  # r8
        ctypes.c_int64,  # r9
        ctypes.c_int64,  # lparam5
        ctypes.c_int64,  # lparam6
        ctypes.c_bool    # 是否主线程调用
    ]

    # 调用C函数
    ret = HCEnv_TestCALL_RetArrayEx(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(线程ID),
        ctypes.c_int64(rcx),
        ctypes.c_int64(rdx),
        ctypes.c_int64(r8),
        ctypes.c_int64(r9),
        ctypes.c_int64(lparam5),
        ctypes.c_int64(lparam6),
        ctypes.c_bool(是否主线程调用)
    )
    return ret


# INT64 __stdcall HCEnv_SetProcessType(int 进程位数);
def HD环境_设置目标进程位数(进程位数: int) -> int:
    """
    设置目标进程位数
    :param 进程位数: 32/64
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HCEnv_SetProcessType = hd.HCEnv_SetProcessType
    HCEnv_SetProcessType.restype = ctypes.c_int64
    HCEnv_SetProcessType.argtypes = [
        ctypes.c_int32  # 进程位数
    ]

    # 调用C函数
    ret = HCEnv_SetProcessType(ctypes.c_int32(进程位数))
    return ret


# INT64 __stdcall HCEnv_SetProcessTypeEx(__int32 窗口序号, __int32 进程位数);
def HD环境_设置目标进程位数Ex(窗口序号: int, 进程位数: int) -> int:
    """
    指定某个序号绑定的进程位数(扩展版本)
    :param 窗口序号: 窗口序号
    :param 进程位数: 32/64
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HCEnv_SetProcessTypeEx = hd.HCEnv_SetProcessTypeEx
    HCEnv_SetProcessTypeEx.restype = ctypes.c_int64
    HCEnv_SetProcessTypeEx.argtypes = [
        ctypes.c_int32,  # 窗口序号
        ctypes.c_int32   # 进程位数
    ]

    # 调用C函数
    ret = HCEnv_SetProcessTypeEx(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(进程位数)
    )
    return ret

# HDHandleEventInfo
# Python 侧定义并确保对齐一致
class HDHandleEventInfo(ctypes.Structure):
    _pack_ = 8  # 对齐方式必须与 C++ 的 #pragma pack(push, 8) 一致
    _fields_ = [
        ("m_callType", ctypes.c_int32),
        ("_padding1", ctypes.c_byte*4),  # 填充4字节，保证后面的8字节对齐
        ("m_call", ctypes.c_int64),
        ("m_rcx", ctypes.c_int64),
        ("m_rdx", ctypes.c_int64),
        ("m_r8", ctypes.c_int64),
        ("m_r9", ctypes.c_int64),
        ("m_lparam5", ctypes.c_int64),
        ("m_lparam6", ctypes.c_int64),
        ("m_lparam7", ctypes.c_int64),
        ("m_lparam8", ctypes.c_int64),
        ("m_value", ctypes.c_int64),
        ("m_size", ctypes.c_int64),
        ("m_buffer", ctypes.c_char * 260),  # 定长字符数组
        ("m_buffer2", ctypes.c_char * 260),  # 定长字符数组
        ("m_pRetValue", ctypes.c_void_p),#值 单独
        ("m_pRetJson", ctypes.c_void_p)#字符串 返回
    ]

#print(ctypes.sizeof(HDHandleEventInfo))  # 应该等于C++中的sizeof(HDHandleEventInfo)
#HDHOOK send HOOK回调
#typedef __int32(__stdcall *HandleEventFunType)(__int32 窗口序号, __int32 插件序号, HDHandleEventInfo Info);
HD_HandleEventFunType_stdcall = ctypes.WINFUNCTYPE(ctypes.c_int32,ctypes.c_int32,ctypes.c_int32,HDHandleEventInfo)


# INT64 __stdcall HCEnv_SetHandleEventCallBack(INT64 funCallBack);
def HD环境_设置中控事件处理回调函数(事件处理回调函数: HD_HandleEventFunType_stdcall) -> int:
    """
    设置中控事件处理回调函数
    :param 事件处理回调函数: 事件处理回调函数(查看HD回调)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HCEnv_SetHandleEventCallBack = hd.HCEnv_SetHandleEventCallBack
    HCEnv_SetHandleEventCallBack.restype = ctypes.c_int64
    HCEnv_SetHandleEventCallBack.argtypes = [
        ctypes.c_int64  # 事件处理回调函数
    ]
    #
    HD_HandleEventFunType_stdcall_Fun = HD_HandleEventFunType_stdcall(事件处理回调函数)
    # 正确获取回调函数的地址并转换为64位整数：使用ctypes.cast将回调对象转换为c_void_p，然后获取其数值并转为c_int64。
    HD_HandleEventFunType_stdcall_Fun_ptr = ctypes.c_int64(ctypes.cast(HD_HandleEventFunType_stdcall_Fun, ctypes.c_void_p).value) if HD_HandleEventFunType_stdcall_Fun else ctypes.c_int64(0)

    # 调用C函数
    ret = HCEnv_SetHandleEventCallBack(HD_HandleEventFunType_stdcall_Fun_ptr)
    return ret

# 定义关闭回调类型
# typedef __int32(__stdcall *ShutDownEventFunType)(__int32 code);
HD_ShutDownEventFunType_stdcall = ctypes.WINFUNCTYPE(ctypes.c_int32, ctypes.c_int32)

def HD环境_设置关闭回调函数(py_callback: HD_ShutDownEventFunType_stdcall) -> int:
    """
    设置关闭回调函数(处理HD功能失效,内部自动关闭中控前的操作)
    Args:
        py_callback: Python函数，签名为 callback(code:int) -> int
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    HCEnv_SetShutDownCallBack = hd.HCEnv_SetShutDownCallBack
    HCEnv_SetShutDownCallBack.restype = ctypes.c_int64
    HCEnv_SetShutDownCallBack.argtypes = [ctypes.c_int64]

    c_callback = HD_ShutDownEventFunType_stdcall(py_callback) if py_callback else None
    callback_ptr = ctypes.c_int64(ctypes.cast(c_callback, ctypes.c_void_p).value) if c_callback else ctypes.c_int64(0)
    ret = HCEnv_SetShutDownCallBack(callback_ptr)
    return ret


# INT64 __stdcall HCEnv_SetCheckComItlTime(int 通讯检测间隔毫秒 = 20);
def HD环境_设置通讯检测间隔(通讯检测间隔毫秒: int = 20) -> int:
    """
    设置通讯检测间隔毫秒(丢弃)
    :param 通讯检测间隔毫秒: 默认就行,越小响应越快,CPU占用了越高(也可以调用HCEnv_InitEx 设置)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HCEnv_SetCheckComItlTime = hd.HCEnv_SetCheckComItlTime
    HCEnv_SetCheckComItlTime.restype = ctypes.c_int64
    HCEnv_SetCheckComItlTime.argtypes = [
        ctypes.c_int32  # 通讯检测间隔毫秒
    ]

    # 调用C函数
    ret = HCEnv_SetCheckComItlTime(ctypes.c_int32(通讯检测间隔毫秒))
    return ret


# INT64 __stdcall HCEnv_SetCheckCallBackTime(int 回调响应毫秒 = 5);
def HD环境_设置回调响应间隔(回调响应毫秒: int = 5) -> int:
    """
    设置回调响应毫秒(丢弃)
    :param 回调响应毫秒: 默认就行,越小响应越快,CPU占用了越高(也可以调用HCEnv_InitEx 设置)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HCEnv_SetCheckCallBackTime = hd.HCEnv_SetCheckCallBackTime
    HCEnv_SetCheckCallBackTime.restype = ctypes.c_int64
    HCEnv_SetCheckCallBackTime.argtypes = [
        ctypes.c_int32  # 回调响应毫秒
    ]

    # 调用C函数
    ret = HCEnv_SetCheckCallBackTime(ctypes.c_int32(回调响应毫秒))
    return ret


# INT64 __stdcall HCEnv_TerminateThread(int 窗口序号, int threadId, BOOL 是否操作锁 = TRUE);
def HD环境_强制结束线程(窗口序号: int, threadId: int, 是否操作锁: bool = True) -> int:
    """
    强制结束当前线程(可以在卸载环境后调用)
    :param 窗口序号: 指定当前强制关闭线程所操作的窗口序号
    :param threadId: 强制关闭的线程ID,调用此接口的线程不要和结束的线程是同一个(虽然内部有检查)
    :param 是否操作锁: 一般为了安全的强制关闭线程,必须为真, 否则会很有可能出现死锁的情况
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HCEnv_TerminateThread = hd.HCEnv_TerminateThread
    HCEnv_TerminateThread.restype = ctypes.c_int64
    HCEnv_TerminateThread.argtypes = [
        ctypes.c_int32,  # 窗口序号
        ctypes.c_int32,  # threadId
        ctypes.c_bool    # 是否操作锁
    ]

    # 调用C函数
    ret = HCEnv_TerminateThread(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(threadId),
        ctypes.c_bool(是否操作锁)
    )
    return ret


# INT64 __stdcall HCEnv_TerminateThreadEx(int 窗口序号, INT64 threadHandle, BOOL 是否操作锁 = TRUE);
def HD环境_强制结束线程Ex(窗口序号: int, threadHandle: int, 是否操作锁: bool = True) -> int:
    """
    强制结束当前线程(可以在卸载环境后调用)(扩展版本)
    :param 窗口序号: 指定当前强制关闭线程所操作的窗口序号
    :param threadHandle: 强制关闭的线程句柄,调用此接口的线程不要和结束的线程是同一个(虽然有检查但是可能会崩溃)
    :param 是否操作锁: 一般为了安全的强制关闭线程,必须为真, 否则会很有可能出现死锁的情况
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HCEnv_TerminateThreadEx = hd.HCEnv_TerminateThreadEx
    HCEnv_TerminateThreadEx.restype = ctypes.c_int64
    HCEnv_TerminateThreadEx.argtypes = [
        ctypes.c_int32,  # 窗口序号
        ctypes.c_int64,  # threadHandle
        ctypes.c_bool    # 是否操作锁
    ]

    # 调用C函数
    ret = HCEnv_TerminateThreadEx(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(threadHandle),
        ctypes.c_bool(是否操作锁)
    )
    return ret


def HD环境_设置窗口排序信息(
    x: int,
    y: int,
    offsetx: int,
    offsety: int,
    cols: int,
    funCallback: ctypes.WINFUNCTYPE(ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32) = None
) -> int:
    """
    接口说明:
        设置窗口排序信息

    函数原型:
        __int64  __stdcall  HCEnv_SetWindowsSortInfo(__int32 x, __int32 y, __int32 offsetx, __int32 offsety,__int32 cols, __int64 funCallbackAddr);

    参数说明:
        x: 屏幕左上角X开始
        y: 屏幕左上角Y开始
        offsetx: 每列左上角的X偏移
        offsety: 每行左上角的Y偏移
        cols: 列数 一排有多少个窗口 -1表示 一排无限窗口
        funCallback: 排序窗口回调  这个在触发正常心跳回调的时候会触发  必须HCEnv_AttachHeart附加心跳 才有效
            回调类型: typedef __int32(__stdcall *WindowsSortFunType)(__int32 窗口索引, __int32 pid, __int32 x, __int32 y);

    返回值:
        int: 见HD返回值表

    备注:
        无
    """
    hd = Config.get_hd()
    HCEnv_SetWindowsSortInfo = hd.HCEnv_SetWindowsSortInfo
    HCEnv_SetWindowsSortInfo.restype = ctypes.c_int64
    HCEnv_SetWindowsSortInfo.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int64]
    # 回调类型定义
    WindowsSortFunType = ctypes.WINFUNCTYPE(ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32)
    funCallback_ptr = ctypes.c_int64(ctypes.cast(WindowsSortFunType(funCallback), ctypes.c_void_p).value) if funCallback else ctypes.c_int64(0)
    ret = HCEnv_SetWindowsSortInfo(
        ctypes.c_int32(x),
        ctypes.c_int32(y),
        ctypes.c_int32(offsetx),
        ctypes.c_int32(offsety),
        ctypes.c_int32(cols),
        funCallback_ptr
    )
    return ret


from .config import Config, ctypes
from .config import auto_encode

import ctypes

# INT64 __stdcall HCFI_FindImageA(int windowsIndex, char* imageNameSet, double sim, BOOL isGrayImage, BOOL openViewer);
def HD智能识图_找图A(窗口序号: int, 图片名字集合: str, 相似度: float = 0.8, 是否灰度图: bool = False, 是否打开查看器: bool = False) -> int:
    """
    识图（返回的是圆型的圆点）（ASCII）
    
    Args:
        窗口序号: 窗口序号（从1开始）
        图片名字集合: 如：hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
        相似度: 相似度0-1，默认0.8
        是否灰度图: 是否灰度图，默认False
        是否打开查看器: 是否打开查看器，默认False
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCFI_FindImageA = hd.HCFI_FindImageA
    HCFI_FindImageA.restype = ctypes.c_int64
    HCFI_FindImageA.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_bool, ctypes.c_bool]
    
    ret = HCFI_FindImageA(
        ctypes.c_int32(窗口序号),
        auto_encode(图片名字集合),
        ctypes.c_double(相似度),
        ctypes.c_bool(是否灰度图),
        ctypes.c_bool(是否打开查看器)
    )
    return ret

# INT64 __stdcall HCFI_FindImageW(int 窗口序号, wchar_t*图片名字集合, double sim, BOOL 是否灰度图, BOOL 是否打开查看器);
def HD智能识图_找图W(窗口序号: int, 图片名字集合: str, 相似度: float = 0.8, 是否灰度图: bool = False, 是否打开查看器: bool = False) -> int:
    """
    识图(返回的是圆型的圆点)(unicode)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        图片名字集合: 如: hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
        相似度: 相似度0-1 (默认0.8)
        是否灰度图: 是否灰度图，默认开启 (默认False)
        是否打开查看器: 是否打开查看器 (默认False)
        
    Returns:
        返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HCFI_FindImageW = hd.HCFI_FindImageW
    HCFI_FindImageW.restype = ctypes.c_int64
    HCFI_FindImageW.argtypes = [ctypes.c_int32, ctypes.c_wchar_p, ctypes.c_double, ctypes.c_bool, ctypes.c_bool]

    # 使用auto_encode自动转换编码
    image_bytes = auto_encode(图片名字集合)

    ret = HCFI_FindImageW(
        ctypes.c_int32(窗口序号),
        image_bytes,
        ctypes.c_double(相似度),
        ctypes.c_bool(是否灰度图),
        ctypes.c_bool(是否打开查看器)
    )

    return ret

# INT64 __stdcall HCFI_FindImageExA(int 窗口序号, char*图片名字集合, double sim = 0.8, BOOL 是否灰度图 = FALSE, BOOL 是否打开查看器 = FALSE);
def HD智能识图_找图ExA(窗口序号: int, 图片名字集合: str, 相似度: float = 0.8, 是否灰度图: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindImageExA(INT32 窗口序号, LPCSTR 图片名字集合, double 相似度, BOOL 是否灰度图, BOOL 是否打开查看器);
    """
    识图(返回的是矩形左上角和右下角)(扩展版本)(ascii)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        图片名字集合: 如:hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
        相似度: 相似度0-1
        是否灰度图: 是否灰度图  一般开启就行
        是否打开查看器: 是否打开
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
             返回数据格式：
             {
               "error":0,
               "ret":AAA,
               "data":[{"x1":XX,"y1":YY,"x2":XX,"y2":YY}],
               "time":ZZZ
             }
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindImageExA
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_bool, ctypes.c_bool]
    
    return func(窗口序号, auto_encode(图片名字集合), 相似度, 是否灰度图, 是否打开查看器)

def HD智能识图_找图ExW(窗口序号: int, 图片名字集合: str, 相似度: float = 0.8, 是否灰度图: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindImageExW(INT32 窗口序号, LPCWSTR 图片名字集合, double 相似度, BOOL 是否灰度图, BOOL 是否打开查看器);
    """
    识图(返回的是矩形左上角和右下角)(扩展版本)(unicode)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        图片名字集合: 如: hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
        相似度: 相似度0-1
        是否灰度图: 是否灰度图，默认开启
        是否打开查看器: 是否打开查看器
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindImageExW
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_wchar_p, ctypes.c_double, ctypes.c_bool, ctypes.c_bool]
    
    return func(窗口序号, 图片名字集合, 相似度, 是否灰度图, 是否打开查看器)

def HD智能识图_范围找图ExA(窗口序号: int, x: int, y: int, w: int, h: int, 图片名字集合: str, 信息类型: int = 0, 相似度: float = 0.8, 是否灰度图: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindRangeImageA(INT32 窗口序号, INT32 x, INT32 y, INT32 w, INT32 h, LPCSTR 图片名字集合, INT32 信息类型, double 相似度, BOOL 是否灰度图, BOOL 是否打开查看器);
    """
    范围内识图 (ascii)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: 起始坐标X
        y: 起始坐标Y
        w: 区域宽度
        h: 区域高度
        图片名字集合: 如: hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
        信息类型: 0表示返回圆点，1表示返回矩形左上角和右下角
        相似度: 相似度0-1
        是否灰度图: 是否灰度图，默认开启
        是否打开查看器: 是否打开查看器
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindRangeImageA
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_int32, ctypes.c_double, ctypes.c_bool, ctypes.c_bool]
    
    return func(窗口序号, x, y, w, h, auto_encode(图片名字集合), 信息类型, 相似度, 是否灰度图, 是否打开查看器)

def HD智能识图_范围找图ExW(窗口序号: int, x: int, y: int, w: int, h: int, 图片名字集合: str, 信息类型: int = 0, 相似度: float = 0.8, 是否灰度图: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindRangeImageW(INT32 窗口序号, INT32 x, INT32 y, INT32 w, INT32 h, LPCWSTR 图片名字集合, INT32 信息类型, double 相似度, BOOL 是否灰度图, BOOL 是否打开查看器);
    """
    范围内识图 (unicode)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: 起始X坐标
        y: 起始Y坐标
        w: 宽度
        h: 高度
        图片名字集合: 图片名字集合 (例如: hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp)
        信息类型: 0表示返回圆点, 1表示返回矩形左上角和右下角
        相似度: 相似度 (0-1)
        是否灰度图: 是否灰度图 (默认False)
        是否打开查看器: 是否打开查看器 (默认False)
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindRangeImageW
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_wchar_p, ctypes.c_int32, ctypes.c_double, ctypes.c_bool, ctypes.c_bool]
    
    return func(窗口序号, x, y, w, h, 图片名字集合, 信息类型, 相似度, 是否灰度图, 是否打开查看器)

def HD智能识图_Tem范围找图A(窗口序号: int, x: int, y: int, w: int, h: int, 图片名字集合: str, 相似度: float = 0.9, 算法类型: int = 5, 是否灰度图: bool = False, 是否全部: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindRangeImageTemA(INT32 窗口序号, INT32 x, INT32 y, INT32 w, INT32 h, LPCSTR 图片名字集合, double 相似度, INT32 算法类型, BOOL 是否灰度图, BOOL 是否全部, BOOL 是否打开查看器);
    """
    Tem范围识图(ascii)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: 起始坐标X
        y: 起始坐标Y
        w: 区域宽度
        h: 区域高度
        图片名字集合: 如: hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
        相似度: 相似度0-1
        算法类型: 0 1 2 3 4 5 一共6种算法，默认使用5
        是否灰度图: 是否灰度图，默认开启
        是否全部: 是否找出全部结果，默认False
        是否打开查看器: 是否打开查看器
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindRangeImageTemA
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32, ctypes.c_bool, ctypes.c_bool, ctypes.c_bool]
    
    return func(窗口序号, x, y, w, h, auto_encode(图片名字集合), 相似度, 算法类型, 是否灰度图, 是否全部, 是否打开查看器)

def HD智能识图_Tem范围找图W(窗口序号: int, x: int, y: int, w: int, h: int, 图片名字集合: str, 相似度: float = 0.9, 算法类型: int = 5, 是否灰度图: bool = False, 是否全部: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindRangeImageTemW(INT32 窗口序号, INT32 x, INT32 y, INT32 w, INT32 h, LPCWSTR 图片名字集合, double 相似度, INT32 算法类型, BOOL 是否灰度图, BOOL 是否全部, BOOL 是否打开查看器);
    """
    Tem范围识图(unicode)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: 起始坐标X
        y: 起始坐标Y
        w: 区域宽度
        h: 区域高度
        图片名字集合: 如: hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
        相似度: 相似度0-1
        算法类型: 0 1 2 3 4 5 一共6种算法，默认使用5
        是否灰度图: 是否灰度图，默认开启
        是否全部: 是否找出全部结果，默认False
        是否打开查看器: 是否打开查看器
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindRangeImageTemW
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_wchar_p, ctypes.c_double, ctypes.c_int32, ctypes.c_bool, ctypes.c_bool, ctypes.c_bool]
    
    return func(窗口序号, x, y, w, h, 图片名字集合, 相似度, 算法类型, 是否灰度图, 是否全部, 是否打开查看器)


def HD智能识图_Tem找图A(窗口序号: int, 图片名字集合: str, 相似度: float = 0.9, 算法类型: int = 5, 是否灰度图: bool = False, 是否全部: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindImageTemA(INT32 窗口序号, LPCSTR 图片名字集合, double 相似度, INT32 算法类型, BOOL 是否灰度图, BOOL 是否全部, BOOL 是否打开查看器);
    """
    Tem识图 (ascii)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        图片名字集合: 图片名字集合 (例如: hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp)
        相似度: 相似度 (0-1)
        算法类型: 算法类型 (0-5, 默认5)
        是否灰度图: 是否灰度图 (默认False)
        是否全部: 是否全部 (默认False)
        是否打开查看器: 是否打开查看器 (默认False)
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindImageTemA
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32, ctypes.c_bool, ctypes.c_bool, ctypes.c_bool]
    
    return func(窗口序号, auto_encode(图片名字集合), 相似度, 算法类型, 是否灰度图, 是否全部, 是否打开查看器)

def HD智能识图_Tem找图W(窗口序号: int, 图片名字集合: str, 相似度: float = 0.9, 算法类型: int = 5, 是否灰度图: bool = False, 是否全部: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindImageTemW(INT32 窗口序号, LPCWSTR 图片名字集合, double 相似度, INT32 算法类型, BOOL 是否灰度图, BOOL 是否全部, BOOL 是否打开查看器);
    """
    Tem识图 (unicode)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        图片名字集合: 图片名字集合 (例如: hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp)
        相似度: 相似度 (0-1)
        算法类型: 算法类型 (0-5, 默认5)
        是否灰度图: 是否灰度图 (默认False)
        是否全部: 是否全部 (默认False)
        是否打开查看器: 是否打开查看器 (默认False)
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindImageTemW
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_wchar_p, ctypes.c_double, ctypes.c_int32, ctypes.c_bool, ctypes.c_bool, ctypes.c_bool]
    
    return func(窗口序号, 图片名字集合, 相似度, 算法类型, 是否灰度图, 是否全部, 是否打开查看器)


def HD智能识图_找图从文件(窗口序号: int, 原图名字: str, 图片名字集合: str, 相似度: float = 0.9, 是否灰度图: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindImageByFile(INT32 窗口序号, LPCSTR 原图名字, LPCSTR 图片名字集合, double 相似度, BOOL 是否灰度图, BOOL 是否打开查看器);
    """
    从文件中加载截图数据并识图(返回的是矩形左上角和右下角)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        原图名字: 指定一张原图文件名(支持绝对路径和相对路径)
        图片名字集合: 如: hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
        相似度: 相似度0-1
        是否灰度图: 是否灰度图，默认开启
        是否打开查看器: 是否打开查看器
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindImageByFile
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_bool, ctypes.c_bool]
    
    return func(窗口序号, auto_encode(原图名字), auto_encode(图片名字集合), 相似度, 是否灰度图, 是否打开查看器)

def HD智能识图_Tem找图从文件(窗口序号: int, 原图名字: str, 图片名字集合: str, 相似度: float = 0.9, 算法类型: int = 5, 是否灰度图: bool = False, 是否全部: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindImageTemByFile(INT32 窗口序号, LPCSTR 原图名字, LPCSTR 图片名字集合, double 相似度, INT32 算法类型, BOOL 是否灰度图, BOOL 是否全部, BOOL 是否打开查看器);
    """
    从文件中加载截图数据并识图(返回的是矩形左上角和右下角)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        原图名字: 指定一张原图文件名(支持绝对路径和相对路径)
        图片名字集合: 如: hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
        相似度: 相似度0-1
        算法类型: 0 1 2 3 4 5 一共6种算法，默认使用5
        是否灰度图: 是否灰度图，默认开启
        是否全部: 是否找出全部结果，默认False
        是否打开查看器: 是否打开查看器
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindImageTemByFile
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32, ctypes.c_bool, ctypes.c_bool, ctypes.c_bool]
    
    return func(窗口序号, auto_encode(原图名字), auto_encode(图片名字集合), 相似度, 算法类型, 是否灰度图, 是否全部, 是否打开查看器)

def HD智能识图_Tem范围找图从文件(窗口序号: int, x: int, y: int, w: int, h: int, 原图名字: str, 图片名字集合: str, 相似度: float = 0.9, 算法类型: int = 5, 是否灰度图: bool = False, 是否全部: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindRangeImageTemByFile(INT32 窗口序号, INT32 x, INT32 y, INT32 w, INT32 h, LPCSTR 原图名字, LPCSTR 图片名字集合, double 相似度, INT32 算法类型, BOOL 是否灰度图, BOOL 是否全部, BOOL 是否打开查看器);
    """
    范围识图(原图从文件)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: 起始坐标X
        y: 起始坐标Y
        w: 区域宽度
        h: 区域高度
        原图名字: 指定一张原图文件名(支持绝对路径和相对路径)
        图片名字集合: 如: hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
        相似度: 相似度0-1
        算法类型: 0 1 2 3 4 5 一共6种算法，默认使用5
        是否灰度图: 是否灰度图，默认开启
        是否全部: 是否找出全部结果，默认False
        是否打开查看器: 是否打开查看器
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindRangeImageTemByFile
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32, ctypes.c_bool, ctypes.c_bool, ctypes.c_bool]
    
    return func(窗口序号, x, y, w, h, auto_encode(原图名字), auto_encode(图片名字集合), 相似度, 算法类型, 是否灰度图, 是否全部, 是否打开查看器)

def HD智能识图_找图从内存(窗口序号: int, 图片字节数据: bytes, 图片字节大小: int, 图片名字集合: str, 相似度: float = 0.8, 是否灰度图: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindImageByMem(INT32 窗口序号, LPVOID 图片字节数据, INT32 图片字节大小, LPCSTR 图片名字集合, double 相似度, BOOL 是否灰度图, BOOL 是否打开查看器);
    """
    从内存中加载截图数据并识图(返回的是矩形左上角和右下角)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        图片字节数据: Bmp图片字节数据缓冲区地址 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        图片字节大小: Bmp图片字节大小
        图片名字集合: 如: hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
        相似度: 相似度0-1
        是否灰度图: 是否灰度图，默认开启
        是否打开查看器: 是否打开查看器
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindImageByMem
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.POINTER(ctypes.c_ubyte), ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_bool, ctypes.c_bool]
    
    # 创建字节数组
    buffer = (ctypes.c_ubyte * len(图片字节数据))(*图片字节数据)
    
    return func(窗口序号, buffer, 图片字节大小, auto_encode(图片名字集合), 相似度, 是否灰度图, 是否打开查看器)

def HD智能识图_Tem找图从内存(窗口序号: int, 图片字节数据: bytes, 图片字节大小: int, 图片名字集合: str, 相似度: float = 0.9, 算法类型: int = 5, 是否灰度图: bool = False, 是否全部: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindImageTemByMem(INT32 窗口序号, LPVOID 图片字节数据, INT32 图片字节大小, LPCSTR 图片名字集合, double 相似度, INT32 算法类型, BOOL 是否灰度图, BOOL 是否全部, BOOL 是否打开查看器);
    """
    范围识图(原图从内存)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        图片字节数据: Bmp图片字节数据缓冲区地址 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        图片字节大小: Bmp图片字节大小
        图片名字集合: 如: hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
        相似度: 相似度0-1
        算法类型: 0 1 2 3 4 5 一共6种算法，默认使用5
        是否灰度图: 是否灰度图，默认开启
        是否全部: 是否找出全部结果，默认False
        是否打开查看器: 是否打开查看器
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindImageTemByMem
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.POINTER(ctypes.c_ubyte), ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32, ctypes.c_bool, ctypes.c_bool, ctypes.c_bool]
    
    # 创建字节数组
    buffer = (ctypes.c_ubyte * len(图片字节数据))(*图片字节数据)
    
    return func(窗口序号, buffer, 图片字节大小, auto_encode(图片名字集合), 相似度, 算法类型, 是否灰度图, 是否全部, 是否打开查看器)

def HD智能识图_Tem范围找图从内存(窗口序号: int, x: int, y: int, w: int, h: int, 图片字节数据: bytes, 图片字节大小: int, 图片名字集合: str, 相似度: float = 0.9, 算法类型: int = 5, 是否灰度图: bool = False, 是否全部: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindRangeImageTemByMem(INT32 窗口序号, INT32 x, INT32 y, INT32 w, INT32 h, LPVOID 图片字节数据, INT32 图片字节大小, LPCSTR 图片名字集合, double 相似度, INT32 算法类型, BOOL 是否灰度图, BOOL 是否全部, BOOL 是否打开查看器);
    """
    范围识图(原图从内存)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: 起始坐标X
        y: 起始坐标Y
        w: 区域宽度
        h: 区域高度
        图片字节数据: Bmp图片字节数据缓冲区地址 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        图片字节大小: Bmp图片字节大小
        图片名字集合: 如: hd1.bmp|hd2.bmp|hd3.bmp|hd4.bmp|
        相似度: 相似度0-1
        算法类型: 0 1 2 3 4 5 一共6种算法，默认使用5
        是否灰度图: 是否灰度图，默认开启
        是否全部: 是否找出全部结果，默认False
        是否打开查看器: 是否打开查看器
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindRangeImageTemByMem
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.POINTER(ctypes.c_ubyte), ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32, ctypes.c_bool, ctypes.c_bool, ctypes.c_bool]
    
    # 创建字节数组
    buffer = (ctypes.c_ubyte * len(图片字节数据))(*图片字节数据)
    
    return func(窗口序号, x, y, w, h, buffer, 图片字节大小, auto_encode(图片名字集合), 相似度, 算法类型, 是否灰度图, 是否全部, 是否打开查看器)


def HD智能识图_Tem找图来源内存(窗口序号: int, 子图内存地址集合字符串: str, 相似度: float = 0.9, 算法类型: int = 5, 是否灰度图: bool = False, 是否全部: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindImageTemFromMem(INT32 窗口序号, LPCSTR 子图内存地址集合字符串, double 相似度, INT32 算法类型, BOOL 是否灰度图, BOOL 是否全部, BOOL 是否打开查看器);
    """
    识图(子图从内存)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        子图内存地址集合字符串: "地址1,长度1|地址2,长度2|地址3,长度3"
        相似度: 相似度0-1
        算法类型: 0 1 2 3 4 5 一共6种算法，默认使用5
        是否灰度图: 是否灰度图，默认开启
        是否全部: 是否找出全部结果，默认False
        是否打开查看器: 是否打开查看器
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindImageTemFromMem
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32, ctypes.c_bool, ctypes.c_bool, ctypes.c_bool]
    
    return func(窗口序号, auto_encode(子图内存地址集合字符串), 相似度, 算法类型, 是否灰度图, 是否全部, 是否打开查看器)


def HD智能识图_Tem范围找图来源内存(窗口序号: int, x: int, y: int, w: int, h: int, 子图内存地址集合字符串: str, 相似度: float = 0.9, 算法类型: int = 5, 是否灰度图: bool = False, 是否全部: bool = False, 是否打开查看器: bool = False) -> int:
    # INT64 __stdcall HCFI_FindRangeImageTemFromMem(INT32 窗口序号, INT32 x, INT32 y, INT32 w, INT32 h, LPCSTR 子图内存地址集合字符串, double 相似度, INT32 算法类型, BOOL 是否灰度图, BOOL 是否全部, BOOL 是否打开查看器);
    """
    范围识图(子图从内存)
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        x: 起始坐标X
        y: 起始坐标Y
        w: 区域宽度
        h: 区域高度
        子图内存地址集合字符串: "地址1,长度1|地址2,长度2|地址3,长度3"
        相似度: 相似度0-1
        算法类型: 0 1 2 3 4 5 一共6种算法，默认使用5
        是否灰度图: 是否灰度图，默认开启
        是否全部: 是否找出全部结果，默认False
        是否打开查看器: 是否打开查看器
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCFI_FindRangeImageTemFromMem
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p, ctypes.c_double, ctypes.c_int32, ctypes.c_bool, ctypes.c_bool, ctypes.c_bool]
    
    return func(窗口序号, x, y, w, h, auto_encode(子图内存地址集合字符串), 相似度, 算法类型, 是否灰度图, 是否全部, 是否打开查看器)












































